@@ -38,6 +38,7 @@ import os
 import re
 import platform
 import subprocess
+import importlib
 try:
     import commands
     from commands import getoutput
@@ -237,6 +238,15 @@ class ModuleSource(ModuleAttributeBase):
                break
         return returnValue     
 
+    def _check_import(self, valueToTest):
+        """Verifies if the system has the requested python import"""
+
+        try:
+            importlib.import_module(valueToTest, package=None)
+        except ImportError:
+            return False
+        return True
+
 class NoneModuleSource(ModuleSource):
     """ This class defines an empty source, i.e. no source code fetching is 
     needed. For compatibility purposes, it is possible to create a given module 
@@ -497,6 +507,8 @@ class SystemDependency(ModuleSource):
                            mandatory=False)
         self.add_attribute('executable_test', None, 'Executable to try to locate',
                            mandatory=False)
+        self.add_attribute('import_test', None, 'Python import to try',
+                           mandatory=False)
         self.add_attribute('try_to_install', 'false', 
                            '(DEPRECATED) If should try to install or not',
                            mandatory=False)
@@ -867,9 +879,10 @@ class GitModuleSource(ModuleSource):
         ModuleSource.__init__(self)
         self.add_attribute('url', '', 'Url to clone the source tree from.',
                            mandatory=True)
-        self.add_attribute('revision', 'refs/remotes/origin/master',
+        self.add_attribute('revision', '',
                            "Revision to checkout. Defaults to origin/master"
                            " reference.")
+        self.add_attribute('branch', '', 'Branch to checkout.')
         self.add_attribute('fetch_option', '', 'Options to add git fetch command.')
     @classmethod
     def name(cls):
@@ -886,6 +899,8 @@ class GitModuleSource(ModuleSource):
             raise TaskError('Attribute type error, expected String, Error: %s' % e1)
         except OSError as e2:
             raise TaskError('Could not create temporary file, Error: %s' % e2)
+
+        checkedOut = False
             
         env.run(['git', 'init'], directory=tempdir)
         env.run(['git', 'remote', 'add', 'origin', self.attribute('url').value],
@@ -895,8 +910,20 @@ class GitModuleSource(ModuleSource):
                     directory=tempdir)
         else:
             env.run(['git', 'fetch'], directory=tempdir)
-        env.run(['git', 'checkout', self.attribute('revision').value],
-                directory=tempdir)
+
+        if self.attribute('branch').value is not '':
+            env.run(['git', 'checkout', self.attribute('branch').value],
+                    directory=tempdir)
+            checkedOut = True
+        
+        if self.attribute('revision').value is not '':
+            env.run(['git', 'checkout', self.attribute('revision').value],
+                    directory=tempdir)
+            checkedOut = True
+
+        if not checkedOut:
+            env.run(['git', 'pull', 'origin', 'master'], directory=tempdir)
+
         os.rename(tempdir, env.srcdir)
 
     def update(self, env):
