@@ -31,8 +31,9 @@ cpp_examples = [
     ("power-adaptation-distance --manager=ns3::AparfWifiManager --outputFileName=aparf --steps=5 --stepsSize=10", "True", "False"),
     ("power-adaptation-distance --manager=ns3::RrpaaWifiManager --outputFileName=rrpaa --steps=5 --stepsSize=10", "True", "False"),
     ("power-adaptation-interference --simuTime=5", "True", "False"),
-    ("ofdm-ht-validation", "True", "True"),
+    ("dsss-validation", "True", "True"),
     ("ofdm-validation", "True", "True"),
+    ("ofdm-ht-validation", "True", "True"),
     ("ofdm-vht-validation", "True", "True"),
     ("ofdm-he-validation", "True", "True"),
     ("80211n-mimo --simulationTime=0.1 --step=10", "True", "True"),
@@ -46,12 +47,16 @@ cpp_examples = [
     ("he-wifi-network --simulationTime=0.3 --frequency=5 --useRts=1 --minExpectedThroughput=6 --maxExpectedThroughput=639", "True", "True"),
     ("he-wifi-network --simulationTime=0.25 --frequency=2.4 --useRts=0 --minExpectedThroughput=6 --maxExpectedThroughput=238", "True", "True"),
     ("he-wifi-network --simulationTime=0.3 --frequency=2.4 --useRts=1 --minExpectedThroughput=6 --maxExpectedThroughput=224", "True", "True"),
-    ("simple-ht-hidden-stations --simulationTime=1 --minExpectedThroughput=22 --maxExpectedThroughput=22.5", "True", "True"),
+    ("simple-ht-hidden-stations --simulationTime=1 --enableRts=0 --nMpdus=32 --minExpectedThroughput=59 --maxExpectedThroughput=60", "True", "True"),
+    ("simple-ht-hidden-stations --simulationTime=1 --enableRts=1 --nMpdus=32 --minExpectedThroughput=57 --maxExpectedThroughput=58", "True", "True"),
     ("mixed-network --simulationTime=1", "True", "True"),
     ("wifi-aggregation --simulationTime=1 --verifyResults=1", "True", "True"),
     ("80211e-txop --simulationTime=1 --verifyResults=1", "True", "True"),
     ("wifi-multi-tos --simulationTime=1 --nWifi=16 --useRts=1 --useShortGuardInterval=1", "True", "True"),
     ("wifi-tcp", "True", "True"),
+    ("wifi-pcf --simulationTime=1 --withData=0", "True", "True"),
+    ("wifi-pcf --simulationTime=1 --withData=1 --trafficDirection=upstream", "True", "True"),
+    ("wifi-pcf --simulationTime=1 --withData=1 --trafficDirection=downstream", "True", "True"),
     ("wifi-hidden-terminal --wifiManager=Arf", "True", "True"),
     ("wifi-hidden-terminal --wifiManager=Aarf", "True", "True"),
     ("wifi-hidden-terminal --wifiManager=Aarfcd", "True", "True"),
