@@ -61,7 +61,7 @@ private:
    * Runs simulation for a while, check if final state & remaining energy is
    * correctly updated.
    */
-  bool StateSwitchTest (WifiPhy::State state);
+  bool StateSwitchTest (WifiPhyState state);
 
 private:
   double m_timeS;     // in seconds
@@ -88,52 +88,52 @@ BasicEnergyUpdateTest::DoRun (void)
   m_energySource.SetTypeId ("ns3::BasicEnergySource");
   m_deviceEnergyModel.SetTypeId ("ns3::WifiRadioEnergyModel");
 
-  uint8_t ret = 0;
-
   // run state switch tests
-  if (StateSwitchTest (WifiPhy::IDLE))
+  if (StateSwitchTest (WifiPhyState::IDLE))
     {
-      ret = 1;
+      return 1;
       std::cerr << "Problem with state switch test (WifiPhy idle)." << std::endl;
     }
-  if (StateSwitchTest (WifiPhy::CCA_BUSY))
+  if (StateSwitchTest (WifiPhyState::CCA_BUSY))
     {
-      ret = 1;
+      return 1;
       std::cerr << "Problem with state switch test (WifiPhy cca busy)." << std::endl;
     }
-  if (StateSwitchTest (WifiPhy::TX))
+  if (StateSwitchTest (WifiPhyState::TX))
     {
-      ret = 1;
+      return 1;
       std::cerr << "Problem with state switch test (WifiPhy tx)." << std::endl;
     }
-  if (StateSwitchTest (WifiPhy::RX))
+  if (StateSwitchTest (WifiPhyState::RX))
     {
-      ret = 1;
+      return 1;
       std::cerr << "Problem with state switch test (WifiPhy rx)." << std::endl;
     }
-  if (StateSwitchTest (WifiPhy::SWITCHING))
+  if (StateSwitchTest (WifiPhyState::SWITCHING))
     {
-      ret = 1;
+      return 1;
       std::cerr << "Problem with state switch test (WifiPhy switching)." << std::endl;
     }
-  if (StateSwitchTest (WifiPhy::SLEEP))
+  if (StateSwitchTest (WifiPhyState::SLEEP))
     {
-      ret = 1;
+      return 1;
       std::cerr << "Problem with state switch test (WifiPhy sleep)." << std::endl;
     }
-  return ret;
+  return 0;
 }
 
 bool
-BasicEnergyUpdateTest::StateSwitchTest (WifiPhy::State state)
+BasicEnergyUpdateTest::StateSwitchTest (WifiPhyState state)
 {
   // create node
   Ptr<Node> node = CreateObject<Node> ();
 
   // create energy source
   Ptr<BasicEnergySource> source = m_energySource.Create<BasicEnergySource> ();
+  source->SetInitialEnergy (50);
   // aggregate energy source to node
   node->AggregateObject (source);
+  source->SetNode (node);
 
   // create device energy model
   Ptr<WifiRadioEnergyModel> model =
@@ -172,7 +172,7 @@ BasicEnergyUpdateTest::StateSwitchTest (WifiPhy::State state)
                        &WifiRadioEnergyModel::ChangeState, devModel, state);
 
   // Calculate remaining energy at simulation stop time
-  Simulator::Schedule (Seconds (m_timeS * 2), 
+  Simulator::Schedule (Seconds (m_timeS * 2),
                        &BasicEnergySource::UpdateEnergySource, source);
 
   double timeDelta = 0.000000001; // 1 nanosecond
@@ -187,34 +187,37 @@ BasicEnergyUpdateTest::StateSwitchTest (WifiPhy::State state)
   double voltage = source->GetSupplyVoltage ();
   estRemainingEnergy -= devModel->GetIdleCurrentA () * voltage * m_timeS;
 
-
   // calculate new state power consumption
   double current = 0.0;
   switch (state)
     {
-    case WifiPhy::IDLE:
+    case WifiPhyState::IDLE:
       current = devModel->GetIdleCurrentA ();
       break;
-    case WifiPhy::CCA_BUSY:
+    case WifiPhyState::CCA_BUSY:
       current = devModel->GetCcaBusyCurrentA ();
       break;
-    case WifiPhy::TX:
+    case WifiPhyState::TX:
       current = devModel->GetTxCurrentA ();
       break;
-    case WifiPhy::RX:
+    case WifiPhyState::RX:
       current = devModel->GetRxCurrentA ();
       break;
-    case WifiPhy::SWITCHING:
+    case WifiPhyState::SWITCHING:
       current = devModel->GetSwitchingCurrentA ();
       break;
-    case WifiPhy::SLEEP:
+    case WifiPhyState::SLEEP:
       current = devModel->GetSleepCurrentA ();
       break;
+    case WifiPhyState::OFF:
+      current = 0;
+      break;
     default:
       NS_FATAL_ERROR ("Undefined radio state: " << state);
       break;
     }
   estRemainingEnergy -= current * voltage * m_timeS;
+  estRemainingEnergy = std::max (0.0, estRemainingEnergy);
 
   // obtain remaining energy from source
   double remainingEnergy = source->GetRemainingEnergy ();
@@ -223,15 +226,15 @@ BasicEnergyUpdateTest::StateSwitchTest (WifiPhy::State state)
   NS_LOG_DEBUG ("Difference is " << estRemainingEnergy - remainingEnergy);
 
   // check remaining energy
-  if ((remainingEnergy > (estRemainingEnergy + m_tolerance)) ||
-      (remainingEnergy < (estRemainingEnergy - m_tolerance)))
+  if ((remainingEnergy > (estRemainingEnergy + m_tolerance))
+      || (remainingEnergy < (estRemainingEnergy - m_tolerance)))
     {
       std::cerr << "Incorrect remaining energy!" << std::endl;
       return true;
     }
 
   // obtain radio state
-  WifiPhy::State endState = devModel->GetCurrentState ();
+  WifiPhyState endState = devModel->GetCurrentState ();
   NS_LOG_DEBUG ("Radio state is " << endState);
   // check end state
   if (endState != state)
@@ -354,14 +357,14 @@ BasicEnergyDepletionTest::DepletionTestCase (double simTimeS,
   WifiHelper wifi;
   wifi.SetStandard (WIFI_PHY_STANDARD_80211b);
 
-  YansWifiPhyHelper wifiPhy =  YansWifiPhyHelper::Default ();
+  YansWifiPhyHelper wifiPhy = YansWifiPhyHelper::Default ();
   /*
    * This is one parameter that matters when using FixedRssLossModel, set it to
    * zero; otherwise, gain will be added.
    */
   wifiPhy.Set ("RxGain", DoubleValue (0));
   // ns-3 supports RadioTap and Prism tracing extensions for 802.11b
-  wifiPhy.SetPcapDataLinkType (YansWifiPhyHelper::DLT_IEEE802_11_RADIO);
+  wifiPhy.SetPcapDataLinkType (WifiPhyHelper::DLT_IEEE802_11_RADIO);
 
   YansWifiChannelHelper wifiChannel;
   wifiChannel.SetPropagationDelay ("ns3::ConstantSpeedPropagationDelayModel");
