@@ -126,6 +126,23 @@ public:
    */
   bool AddAllocated (const Ipv4Address addr);
 
+  /**
+   * \brief Check the Ipv4Address allocation in the list of IPv4 entries
+   *
+   * \param addr The Ipv4Address to be checked in the list of Ipv4 entries
+   * \returns true if the address is already allocated
+   */
+  bool IsAddressAllocated (const Ipv4Address addr);
+
+  /**
+   * \brief Check if a network has already allocated addresses
+   *
+   * \param addr The Ipv4 network to be checked
+   * \param mask The Ipv4 network mask
+   * \returns true if the network is already allocated
+   */
+  bool IsNetworkAllocated (const Ipv4Address addr, const Ipv4Mask mask);
+
   /**
    * \brief Used to turn off fatal errors and assertions, for testing
    */
@@ -412,7 +429,7 @@ Ipv4AddressGeneratorImpl::AddAllocated (const Ipv4Address address)
 // If we get here, we know that the next lower block of addresses couldn't 
 // have been extended to include this new address since the code immediately 
 // above would have been executed and that next lower block extended upward.
-// So we know it's safe to extend the current block down to includ the new
+// So we know it's safe to extend the current block down to include the new
 // address.
 //
       if (addr == (*i).addrLow - 1)
@@ -429,6 +446,58 @@ Ipv4AddressGeneratorImpl::AddAllocated (const Ipv4Address address)
   return true;
 }
 
+bool
+Ipv4AddressGeneratorImpl::IsAddressAllocated (const Ipv4Address address)
+{
+  NS_LOG_FUNCTION (this << address);
+
+  uint32_t addr = address.Get ();
+
+  NS_ABORT_MSG_UNLESS (addr, "Ipv4AddressGeneratorImpl::IsAddressAllocated(): Don't check for the broadcast address...");
+
+  std::list<Entry>::iterator i;
+
+  for (i = m_entries.begin (); i != m_entries.end (); ++i)
+    {
+      NS_LOG_LOGIC ("examine entry: " << Ipv4Address ((*i).addrLow) <<
+                    " to " << Ipv4Address ((*i).addrHigh));
+      if (addr >= (*i).addrLow && addr <= (*i).addrHigh)
+        {
+          NS_LOG_LOGIC ("Ipv4AddressGeneratorImpl::IsAddressAllocated(): Address Collision: " << Ipv4Address (addr));
+          return false;
+        }
+    }
+  return true;
+}
+
+bool
+Ipv4AddressGeneratorImpl::IsNetworkAllocated (const Ipv4Address address, const Ipv4Mask mask)
+{
+  NS_LOG_FUNCTION (this << address << mask);
+
+  NS_ABORT_MSG_UNLESS (address == address.CombineMask (mask),
+                       "Ipv4AddressGeneratorImpl::IsNetworkAllocated(): network address and mask don't match " << address << " " << mask);
+
+  std::list<Entry>::iterator i;
+
+  for (i = m_entries.begin (); i != m_entries.end (); ++i)
+    {
+      NS_LOG_LOGIC ("examine entry: " << Ipv4Address ((*i).addrLow) << " to " << Ipv4Address ((*i).addrHigh));
+      Ipv4Address low = Ipv4Address ((*i).addrLow);
+      Ipv4Address high = Ipv4Address ((*i).addrHigh);
+
+      if (address == low.CombineMask (mask) || address == high.CombineMask (mask))
+        {
+          NS_LOG_LOGIC ("Ipv4AddressGeneratorImpl::IsNetworkAllocated(): Network already allocated: " <<
+                        address << " " << low << "-" << high);
+          return false;
+        }
+
+    }
+  return true;
+}
+
+
 void
 Ipv4AddressGeneratorImpl::TestMode (void)
 {
@@ -546,6 +615,24 @@ Ipv4AddressGenerator::AddAllocated (const Ipv4Address addr)
          ->AddAllocated (addr);
 }
 
+bool
+Ipv4AddressGenerator::IsAddressAllocated (const Ipv4Address addr)
+{
+  NS_LOG_FUNCTION_NOARGS ();
+
+  return SimulationSingleton<Ipv4AddressGeneratorImpl>::Get ()
+         ->IsAddressAllocated (addr);
+}
+
+bool
+Ipv4AddressGenerator::IsNetworkAllocated (const Ipv4Address addr, const Ipv4Mask mask)
+{
+  NS_LOG_FUNCTION_NOARGS ();
+
+  return SimulationSingleton<Ipv4AddressGeneratorImpl>::Get ()
+         ->IsNetworkAllocated (addr, mask);
+}
+
 void
 Ipv4AddressGenerator::TestMode (void)
 {
