@@ -95,6 +95,8 @@ public:
    */
   void SetNode (Ptr<Node> node);
 
+  // NOTE: API from here should not be removed, only added. Be backward-compatible!
+
   /**
    * \brief Create a TCP socket using the TypeId set by SocketType attribute
    *
@@ -112,7 +114,18 @@ public:
    * \warning using a congestionTypeId other than TCP is a bad idea.
    *
    * \param congestionTypeId the congestion control algorithm TypeId
+   * \param recoveryTypeId the recovery algorithm TypeId
    */
+  Ptr<Socket> CreateSocket (TypeId congestionTypeId, TypeId recoveryTypeId);
+
+  /**
+    * \brief Create a TCP socket using the specified congestion control algorithm
+    * \return A smart Socket pointer to a TcpSocket allocated by this instance
+    * of the TCP protocol
+    *
+    * \param congestionTypeId the congestion control algorithm TypeId
+    *
+    */
   Ptr<Socket> CreateSocket (TypeId congestionTypeId);
 
   /**
@@ -306,6 +319,7 @@ private:
   Ipv6EndPointDemux *m_endPoints6; //!< A list of IPv6 end points.
   TypeId m_rttTypeId;              //!< The RTT Estimator TypeId
   TypeId m_congestionTypeId;       //!< The socket TypeId
+  TypeId m_recoveryTypeId;         //!< The recovery TypeId
   std::vector<Ptr<TcpSocketBase> > m_sockets;      //!< list of sockets
   IpL4Protocol::DownTargetCallback m_downTarget;   //!< Callback to send packets over IPv4
   IpL4Protocol::DownTargetCallback6 m_downTarget6; //!< Callback to send packets over IPv6
