@@ -23,6 +23,7 @@
 #include "ns3/error-model.h"
 #include "ns3/tcp-socket-base.h"
 #include "ns3/tcp-congestion-ops.h"
+#include "ns3/tcp-recovery-ops.h"
 #include "ns3/test.h"
 
 namespace ns3 {
@@ -322,6 +323,18 @@ protected:
   virtual Ptr<TcpSocketMsgBase> CreateSocket (Ptr<Node> node, TypeId socketType,
                                               TypeId congControl);
 
+  /**
+   * \brief Create a socket
+   *
+   * \param node associated node
+   * \param socketType Type of the TCP socket
+   * \param congControl congestion control
+   * \param recoveryAlgorithm recovery algorithm
+   * \return a pointer to the newer created socket
+   */
+  virtual Ptr<TcpSocketMsgBase> CreateSocket (Ptr<Node> node, TypeId socketType,
+                                              TypeId congControl, TypeId recoveryAlgorithm);
+
   /**
    * \brief Get the pointer to a previously created sender socket
    * \return ptr to sender socket or 0
@@ -359,7 +372,7 @@ protected:
   virtual void DoRun (void);
 
   /**
-   * \brief Change the configuration of the evironment
+   * \brief Change the configuration of the environment
    */
   virtual void ConfigureEnvironment (void);
 
@@ -466,7 +479,7 @@ protected:
   Time GetRto (SocketWho who);
 
   /**
-   * \brief Get the minimun RTO attribute
+   * \brief Get the minimum RTO attribute
    *
    * \param who node to get the parameter from
    * \return minimum RTO time
@@ -569,6 +582,14 @@ protected:
    */
   void SetInitialCwnd (SocketWho who, uint32_t initialCwnd);
 
+  /**
+   * \brief Forcefully set the ecn mode on
+   *
+   * \param who socket to force
+   * \param ecnMode Mode of ECN. Currently NoEcn and ClassicEcn is supported.
+   */
+  void SetEcn (SocketWho who, TcpSocketBase::EcnMode_t ecnMode);
+
   /**
    * \brief Forcefully set the initial ssth
    *
@@ -623,6 +644,13 @@ protected:
    */
   void SetCongestionControl (TypeId congControl) { m_congControlTypeId = congControl; }
 
+  /**
+   * \brief recovery algorithm of the sender socket
+   *
+   * \param recovery typeid of the recovery algorithm
+   */
+  void SetRecoveryAlgorithm (TypeId reccovery) { m_recoveryTypeId = reccovery; }
+
   /**
    * \brief MTU of the bottleneck link
    *
@@ -654,6 +682,18 @@ protected:
     NS_UNUSED (newValue);
   }
 
+  /**
+   * \brief Tracks the inflated congestion window changes
+   *
+   * \param oldValue old value
+   * \param newValue new value
+   */
+  virtual void CWndInflTrace (uint32_t oldValue, uint32_t newValue)
+  {
+    NS_UNUSED (oldValue);
+    NS_UNUSED (newValue);
+  }
+
   /**
    * \brief Rtt changes
    *
@@ -943,6 +983,7 @@ protected:
   }
 
   TypeId   m_congControlTypeId;      //!< Congestion control
+  TypeId   m_recoveryTypeId;         //!< Recovery
 
 private:
   // Member variables, accessible through getters
