@@ -81,6 +81,7 @@ TcpHyblaIncrementTest::TcpHyblaIncrementTest (uint32_t cWnd, uint32_t ssThresh,
 void
 TcpHyblaIncrementTest::RhoUpdated (double oldVal, double newVal)
 {
+  NS_UNUSED (oldVal);
   m_rho = newVal;
 }
 
@@ -92,6 +93,7 @@ TcpHyblaIncrementTest::DoRun ()
   m_state->m_cWnd = m_cWnd;
   m_state->m_ssThresh = m_ssThresh;
   m_state->m_segmentSize = m_segmentSize;
+  m_state->m_minRtt = m_rtt;
 
   Ptr<TcpHybla> cong = CreateObject <TcpHybla> ();
 
@@ -107,7 +109,7 @@ TcpHyblaIncrementTest::DoRun ()
 
   double calcRho = std::max (m_rtt.GetSeconds () / rRtt.Get ().GetSeconds (), 1.0);
 
-  NS_TEST_ASSERT_MSG_NE (m_rho, 0,
+  NS_TEST_ASSERT_MSG_NE (m_rho, 0.0,
                          "Rho never updated by implementation");
   NS_TEST_ASSERT_MSG_EQ_TOL (calcRho, m_rho, MilliSeconds (10),
                          "Different rho values between implementation and test");
