@@ -74,7 +74,7 @@ public:
   /** 
    * Add an eNB to the EPC
    * 
-   * \param enbNode the previosuly created eNB node which is to be
+   * \param enbNode the previously created eNB node which is to be
    * added to the EPC
    * \param lteEnbNetDevice the LteEnbNetDevice of the eNB node
    * \param cellId ID of the eNB
@@ -82,7 +82,7 @@ public:
   virtual void AddEnb (Ptr<Node> enbNode, Ptr<NetDevice> lteEnbNetDevice, uint16_t cellId) = 0;
 
   /** 
-   * Notify the EPC of the existance of a new UE which might attach at a later time
+   * Notify the EPC of the existence of a new UE which might attach at a later time
    * 
    * \param ueLteDevice the UE device to be attached
    * \param imsi the unique identifier of the UE
@@ -131,6 +131,15 @@ public:
    */
   virtual Ipv4InterfaceContainer AssignUeIpv4Address (NetDeviceContainer ueDevices) = 0;
 
+  /**
+   * Assign IPv6 addresses to UE devices
+   *
+   * \param ueDevices the set of UE devices
+   *
+   * \return the interface container, \see Ipv6AddressHelper::Assign() which has similar semantics
+   */
+  virtual Ipv6InterfaceContainer AssignUeIpv6Address (NetDeviceContainer ueDevices) = 0;
+
 
   /** 
    * 
@@ -138,6 +147,12 @@ public:
    */
   virtual Ipv4Address GetUeDefaultGatewayAddress () = 0;
 
+  /**
+   *
+   * \return the IPv6 address of the Default Gateway to be used by UEs to reach the internet
+   */
+  virtual Ipv6Address GetUeDefaultGatewayAddress6 () = 0;
+
 
 };
 
