@@ -890,7 +890,7 @@ TdMtFfMacScheduler::DoSchedDlTriggerReq (const struct FfMacSchedSapProvider::Sch
        }
      else
        {
-         wbCqi = 1; // lowest value fro trying a transmission
+         wbCqi = 1; // lowest value for trying a transmission
        }
      
      if (wbCqi != 0)
@@ -1065,7 +1065,7 @@ TdMtFfMacScheduler::DoSchedDlTriggerReq (const struct FfMacSchedSapProvider::Sch
           (*itHarqTimer).second.at (newDci.m_harqProcess) = 0;
         }
 
-      // ...more parameters -> ingored in this version
+      // ...more parameters -> ignored in this version
 
       ret.m_buildDataList.push_back (newEl);
 
