@@ -264,6 +264,19 @@ Packet::AddHeader (const Header &header)
   m_metadata.AddHeader (header, size);
 }
 uint32_t
+Packet::RemoveHeader (Header &header, uint32_t size)
+{
+  Buffer::Iterator end;
+  end = m_buffer.Begin ();
+  end.Next (size);
+  uint32_t deserialized = header.Deserialize (m_buffer.Begin (), end);
+  NS_LOG_FUNCTION (this << header.GetInstanceTypeId ().GetName () << deserialized);
+  m_buffer.RemoveAtStart (deserialized);
+  m_byteTagList.Adjust (-deserialized);
+  m_metadata.RemoveHeader (header, deserialized);
+  return deserialized;
+}
+uint32_t
 Packet::RemoveHeader (Header &header)
 {
   uint32_t deserialized = header.Deserialize (m_buffer.Begin ());
@@ -280,6 +293,16 @@ Packet::PeekHeader (Header &header) const
   NS_LOG_FUNCTION (this << header.GetInstanceTypeId ().GetName () << deserialized);
   return deserialized;
 }
+uint32_t
+Packet::PeekHeader (Header &header, uint32_t size) const
+{
+  Buffer::Iterator end;
+  end = m_buffer.Begin ();
+  end.Next (size);
+  uint32_t deserialized = header.Deserialize (m_buffer.Begin (), end);
+  NS_LOG_FUNCTION (this << header.GetInstanceTypeId ().GetName () << deserialized);
+  return deserialized;
+}
 void
 Packet::AddTrailer (const Trailer &trailer)
 {
@@ -445,7 +468,22 @@ Packet::Print (std::ostream &os) const
                 NS_ASSERT (instance != 0);
                 Chunk *chunk = dynamic_cast<Chunk *> (instance);
                 NS_ASSERT (chunk != 0);
-                chunk->Deserialize (item.current);
+                if (item.type == PacketMetadata::Item::HEADER)
+                  {
+                    Buffer::Iterator end = item.current;
+                    end.Next (item.currentSize); // move from start 
+                    chunk->Deserialize (item.current, end);
+                  }
+                else if (item.type == PacketMetadata::Item::TRAILER)
+                  {
+                    Buffer::Iterator start = item.current;
+                    start.Prev (item.currentSize); // move from end
+                    chunk->Deserialize (start, item.current);
+                  }
+                else
+                  {
+                    chunk->Deserialize (item.current);
+                  }    
                 chunk->Print (os);
                 delete chunk;
               }
