@@ -116,29 +116,14 @@ public:
   static TypeId GetTypeId (void);
 
   // inherited from SpectrumChannel
-  virtual void AddPropagationLossModel (Ptr<PropagationLossModel> loss);
-  virtual void AddSpectrumPropagationLossModel (Ptr<SpectrumPropagationLossModel> loss);
-  virtual void SetPropagationDelayModel (Ptr<PropagationDelayModel> delay);
   virtual void AddRx (Ptr<SpectrumPhy> phy);
   virtual void StartTx (Ptr<SpectrumSignalParameters> params);
 
 
   // inherited from Channel
-  virtual uint32_t GetNDevices (void) const;
-  virtual Ptr<NetDevice> GetDevice (uint32_t i) const;
+  virtual std::size_t GetNDevices (void) const;
+  virtual Ptr<NetDevice> GetDevice (std::size_t i) const;
 
-  /**
-   * Get the frequency-dependent propagation loss model.
-   * \returns a pointer to the propagation loss model.
-   */
-  virtual Ptr<SpectrumPropagationLossModel> GetSpectrumPropagationLossModel (void);
-
-  /**
-   * TracedCallback signature for Ptr<const SpectrumSignalParameters>.
-   *
-   * \param [in] params SpectrumSignalParameters instance.
-   */
-  typedef void (* SignalParametersTracedCallback) (Ptr<SpectrumSignalParameters> params);
 
 protected:
   void DoDispose ();
@@ -147,39 +132,23 @@ private:
   /**
    * This method checks if m_rxSpectrumModelInfoMap contains an entry
    * for the given TX SpectrumModel. If such entry exists, it returns
-   * an interator pointing to it. If not, it creates a new entry in
+   * an iterator pointing to it. If not, it creates a new entry in
    * m_txSpectrumMpodelInfoMap, and returns an iterator to it.
    *
-   * @param txSpectrumModel The TX SpectrumModel  being considered
+   * \param txSpectrumModel The TX SpectrumModel  being considered
    *
-   * @return An iterator pointing to the corresponding entry in m_txSpectrumModelInfoMap
+   * \return An iterator pointing to the corresponding entry in m_txSpectrumModelInfoMap
    */
   TxSpectrumModelInfoMap_t::const_iterator FindAndEventuallyAddTxSpectrumModel (Ptr<const SpectrumModel> txSpectrumModel);
 
   /**
    * Used internally to reschedule transmission after the propagation delay.
    *
-   * @param params The signal paramters.
-   * @param receiver A pointer to the receiver SpectrumPhy.
+   * \param params The signal parameters.
+   * \param receiver A pointer to the receiver SpectrumPhy.
    */
   virtual void StartRx (Ptr<SpectrumSignalParameters> params, Ptr<SpectrumPhy> receiver);
 
-  /**
-   * Propagation delay model to be used with this channel.
-   */
-  Ptr<PropagationDelayModel> m_propagationDelay;
-
-  /**
-   * Single-frequency propagation loss model to be used with this channel.
-   */
-  Ptr<PropagationLossModel> m_propagationLoss;
-
-  /**
-   * Frequency-dependent propagation loss model to be used with this channel.
-   */
-  Ptr<SpectrumPropagationLossModel> m_spectrumPropagationLoss;
-
-
   /**
    * Data structure holding, for each TX SpectrumModel,  all the
    * converters to any RX SpectrumModel, and all the corresponding
@@ -198,25 +167,8 @@ private:
   /**
    * Number of devices connected to the channel.
    */
-  uint32_t m_numDevices;
+  std::size_t m_numDevices;
 
-  /**
-   * Maximum loss [dB].
-   *
-   * Any device above this loss is considered out of range.
-   */
-  double m_maxLossDb;
-
-  /**
-   * \deprecated The non-const \c Ptr<SpectrumPhy> argument
-   * is deprecated and will be changed to \c Ptr<const SpectrumPhy>
-   * in a future release.
-   */
-  TracedCallback<Ptr<SpectrumPhy>, Ptr<SpectrumPhy>, double > m_pathLossTrace;
-  /**
-   * Traced callback for SpectrumSignalParameters in StartTx requests
-   */
-  TracedCallback<Ptr<SpectrumSignalParameters> > m_txSigParamsTrace;
 };
 
 
