@@ -55,9 +55,6 @@ SingleModelSpectrumChannel::DoDispose ()
   NS_LOG_FUNCTION (this);
   m_phyList.clear ();
   m_spectrumModel = 0;
-  m_propagationDelay = 0;
-  m_propagationLoss = 0;
-  m_spectrumPropagationLoss = 0;
   SpectrumChannel::DoDispose ();
 }
 
@@ -69,34 +66,6 @@ SingleModelSpectrumChannel::GetTypeId (void)
     .SetParent<SpectrumChannel> ()
     .SetGroupName ("Spectrum")
     .AddConstructor<SingleModelSpectrumChannel> ()
-    .AddAttribute ("MaxLossDb",
-                   "If a single-frequency PropagationLossModel is used, "
-                   "this value represents the maximum loss in dB for which "
-                   "transmissions will be passed to the receiving PHY. "
-                   "Signals for which the PropagationLossModel returns "
-                   "a loss bigger than this value will not be propagated "
-                   "to the receiver. This parameter is to be used to reduce "
-                   "the computational load by not propagating signals "
-                   "that are far beyond the interference range. Note that "
-                   "the default value corresponds to considering all signals "
-                   "for reception. Tune this value with care. ",
-                   DoubleValue (1.0e9),
-                   MakeDoubleAccessor (&SingleModelSpectrumChannel::m_maxLossDb),
-                   MakeDoubleChecker<double> ())
-    .AddTraceSource ("PathLoss",
-                     "This trace is fired whenever a new path loss value "
-                     "is calculated. The first and second parameters "
-                     "to the trace are pointers respectively to the TX and "
-                     "RX SpectrumPhy instances, whereas the third parameters "
-                     "is the loss value in dB. Note that the loss value "
-                     "reported by this trace is the single-frequency loss "
-                     "value obtained by evaluating only the TX and RX "
-                     "AntennaModels and the PropagationLossModel. "
-                     "In particular, note that SpectrumPropagationLossModel "
-                     "(even if present) is never used to evaluate the "
-                     "loss value reported in this trace. ",
-                     MakeTraceSourceAccessor (&SingleModelSpectrumChannel::m_pathLossTrace),
-                     "ns3::SpectrumChannel::LossTracedCallback")
   ;
   return tid;
 }
@@ -117,6 +86,9 @@ SingleModelSpectrumChannel::StartTx (Ptr<SpectrumSignalParameters> txParams)
   NS_ASSERT_MSG (txParams->psd, "NULL txPsd");
   NS_ASSERT_MSG (txParams->txPhy, "NULL txPhy");
 
+  Ptr<SpectrumSignalParameters> txParamsTrace = txParams->Copy (); // copy it since traced value cannot be const (because of potential underlying DynamicCasts)
+  m_txSigParamsTrace (txParamsTrace);
+
   // just a sanity check routine. We might want to remove it to save some computational load -- one "if" statement  ;-)
   if (m_spectrumModel == 0)
     {
@@ -207,7 +179,6 @@ SingleModelSpectrumChannel::StartTx (Ptr<SpectrumSignalParameters> txParams)
             }
         }
     }
-
 }
 
 void
@@ -217,62 +188,19 @@ SingleModelSpectrumChannel::StartRx (Ptr<SpectrumSignalParameters> params, Ptr<S
   receiver->StartRx (params);
 }
 
-
-
-uint32_t
+std::size_t
 SingleModelSpectrumChannel::GetNDevices (void) const
 {
   NS_LOG_FUNCTION (this);
   return m_phyList.size ();
 }
 
-
 Ptr<NetDevice>
-SingleModelSpectrumChannel::GetDevice (uint32_t i) const
+SingleModelSpectrumChannel::GetDevice (std::size_t i) const
 {
   NS_LOG_FUNCTION (this << i);
   return m_phyList.at (i)->GetDevice ()->GetObject<NetDevice> ();
 }
 
 
-void
-SingleModelSpectrumChannel::AddPropagationLossModel (Ptr<PropagationLossModel> loss)
-{
-  NS_LOG_FUNCTION (this << loss);
-  if (m_propagationLoss)
-    {
-      loss->SetNext (m_propagationLoss);
-    }
-  m_propagationLoss = loss;
-}
-
-
-void
-SingleModelSpectrumChannel::AddSpectrumPropagationLossModel (Ptr<SpectrumPropagationLossModel> loss)
-{
-  NS_LOG_FUNCTION (this << loss);
-  if (m_spectrumPropagationLoss)
-    {
-      loss->SetNext (m_spectrumPropagationLoss);
-    }
-  m_spectrumPropagationLoss = loss;
-}
-
-void
-SingleModelSpectrumChannel::SetPropagationDelayModel (Ptr<PropagationDelayModel> delay)
-{
-  NS_LOG_FUNCTION (this << delay);
-  NS_ASSERT (m_propagationDelay == 0);
-  m_propagationDelay = delay;
-}
-
-
-Ptr<SpectrumPropagationLossModel>
-SingleModelSpectrumChannel::GetSpectrumPropagationLossModel (void)
-{
-  NS_LOG_FUNCTION (this);
-  return m_spectrumPropagationLoss;
-}
-
-
 } // namespace ns3
