@@ -232,7 +232,7 @@ int main (int argc, char *argv[])
   uint32_t numOfDownLoadOnOffFlows = 1;   // # of download onoff flows
   bool isPcapEnabled = true;
 
-  float startTime = 0.1;
+  float startTime = 0.1f;
   float simDuration = 60;        //in seconds
 
   std::string fileNamePrefix = "codel-vs-pfifo-fast-asymmetric";
@@ -280,9 +280,10 @@ int main (int argc, char *argv[])
     }
 
   // Queue defaults
-  Config::SetDefault ("ns3::PfifoFastQueueDisc::Limit", UintegerValue (queueSize));
-  Config::SetDefault ("ns3::CoDelQueueDisc::MaxPackets", UintegerValue (queueSize));
-  Config::SetDefault ("ns3::CoDelQueueDisc::Mode", StringValue ("QUEUE_DISC_MODE_PACKETS"));
+  Config::SetDefault ("ns3::PfifoFastQueueDisc::MaxSize",
+                      QueueSizeValue (QueueSize (QueueSizeUnit::PACKETS, queueSize)));
+  Config::SetDefault ("ns3::CoDelQueueDisc::MaxSize",
+                      QueueSizeValue (QueueSize (QueueSizeUnit::PACKETS, queueSize)));
 
   // Create the nodes
   NS_LOG_INFO ("Create nodes");
