@@ -108,17 +108,9 @@ TypeId FqCoDelQueueDisc::GetTypeId (void)
                    StringValue ("5ms"),
                    MakeStringAccessor (&FqCoDelQueueDisc::m_target),
                    MakeStringChecker ())
-    .AddAttribute ("PacketLimit",
-                   "The hard limit on the real queue size, measured in packets",
-                   UintegerValue (10 * 1024),
-                   MakeUintegerAccessor (&FqCoDelQueueDisc::SetLimit,
-                                         &FqCoDelQueueDisc::GetLimit),
-                   MakeUintegerChecker<uint32_t> (),
-                   TypeId::DEPRECATED,
-                   "Use the MaxSize attribute instead")
     .AddAttribute ("MaxSize",
                    "The maximum number of packets accepted by this queue disc",
-                   QueueSizeValue (QueueSize ("0p")),
+                   QueueSizeValue (QueueSize ("10240p")),
                    MakeQueueSizeAccessor (&QueueDisc::SetMaxSize,
                                           &QueueDisc::GetMaxSize),
                    MakeQueueSizeChecker ())
@@ -132,6 +124,11 @@ TypeId FqCoDelQueueDisc::GetTypeId (void)
                    UintegerValue (64),
                    MakeUintegerAccessor (&FqCoDelQueueDisc::m_dropBatchSize),
                    MakeUintegerChecker<uint32_t> ())
+    .AddAttribute ("Perturbation",
+                   "The salt used as an additional input to the hash function used to classify packets",
+                   UintegerValue (0),
+                   MakeUintegerAccessor (&FqCoDelQueueDisc::m_perturbation),
+                   MakeUintegerChecker<uint32_t> ())
   ;
   return tid;
 }
@@ -166,16 +163,27 @@ FqCoDelQueueDisc::DoEnqueue (Ptr<QueueDiscItem> item)
 {
   NS_LOG_FUNCTION (this << item);
 
-  int32_t ret = Classify (item);
+  uint32_t h = 0;
 
-  if (ret == PacketFilter::PF_NO_MATCH)
+  if (GetNPacketFilters () == 0)
     {
-      NS_LOG_ERROR ("No filter has been able to classify this packet, drop it.");
-      DropBeforeEnqueue (item, UNCLASSIFIED_DROP);
-      return false;
+      h = item->Hash (m_perturbation) % m_flows;
     }
+  else
+    {
+      int32_t ret = Classify (item);
 
-  uint32_t h = ret % m_flows;
+      if (ret != PacketFilter::PF_NO_MATCH)
+        {
+          h = ret % m_flows;
+        }
+      else
+        {
+          NS_LOG_ERROR ("No filter has been able to classify this packet, drop it.");
+          DropBeforeEnqueue (item, UNCLASSIFIED_DROP);
+          return false;
+        }
+    }
 
   Ptr<FqCoDelFlow> flow;
   if (m_flowsIndices.find (h) == m_flowsIndices.end ())
@@ -294,28 +302,6 @@ FqCoDelQueueDisc::DoDequeue (void)
   return item;
 }
 
-Ptr<const QueueDiscItem>
-FqCoDelQueueDisc::DoPeek (void)
-{
-  NS_LOG_FUNCTION (this);
-
-  return PeekDequeued ();
-}
-
-void
-FqCoDelQueueDisc::SetLimit (uint32_t limit)
-{
-  NS_LOG_FUNCTION (this << limit);
-  SetMaxSize (QueueSize (QueueSizeUnit::PACKETS, limit));
-}
-
-uint32_t
-FqCoDelQueueDisc::GetLimit (void) const
-{
-  NS_LOG_FUNCTION (this);
-  return GetMaxSize ().GetValue ();
-}
-
 bool
 FqCoDelQueueDisc::CheckConfig (void)
 {
@@ -326,12 +312,6 @@ FqCoDelQueueDisc::CheckConfig (void)
       return false;
     }
 
-  if (GetNPacketFilters () == 0)
-    {
-      NS_LOG_ERROR ("FqCoDelQueueDisc needs at least a packet filter");
-      return false;
-    }
-
   if (GetNInternalQueues () > 0)
     {
       NS_LOG_ERROR ("FqCoDelQueueDisc cannot have internal queues");
