@@ -9,16 +9,19 @@
 # See test.py for more information.
 cpp_examples = [
     ("adaptive-red-tests --testNumber=1", "True", "True"),
-    ("adaptive-red-tests --testNumber=2", "True", "False"),
-    ("adaptive-red-tests --testNumber=6", "True", "False"),
-    ("adaptive-red-tests --testNumber=7", "True", "False"),
-    ("adaptive-red-tests --testNumber=8", "True", "False"),
-    ("adaptive-red-tests --testNumber=9", "True", "False"),
-    ("adaptive-red-tests --testNumber=10", "True", "False"),
-    ("adaptive-red-tests --testNumber=12", "True", "False"),
-    ("adaptive-red-tests --testNumber=13", "True", "False"),
-    ("adaptive-red-tests --testNumber=14", "True", "False"),
-    ("adaptive-red-tests --testNumber=15", "True", "False"),
+    ("adaptive-red-tests --testNumber=2", "True", "True"),
+    ("adaptive-red-tests --testNumber=3", "True", "True"),
+    ("adaptive-red-tests --testNumber=4", "True", "True"),
+    ("adaptive-red-tests --testNumber=6", "True", "True"),
+    ("adaptive-red-tests --testNumber=7", "True", "True"),
+    ("adaptive-red-tests --testNumber=8", "True", "True"),
+    ("adaptive-red-tests --testNumber=9", "True", "True"),
+    ("adaptive-red-tests --testNumber=10", "True", "True"),
+    ("adaptive-red-tests --testNumber=11", "True", "True"),
+    ("adaptive-red-tests --testNumber=12", "True", "True"),
+    ("adaptive-red-tests --testNumber=13", "True", "True"),
+    ("adaptive-red-tests --testNumber=14", "True", "True"),
+    ("adaptive-red-tests --testNumber=15", "True", "True"),
     ("codel-vs-pfifo-asymmetric --routerWanQueueDiscType=PfifoFast --simDuration=10", "True", "True"),
     ("codel-vs-pfifo-asymmetric --routerWanQueueDiscType=CoDel --simDuration=10", "True", "False"),
     ("codel-vs-pfifo-basic-test --queueDiscType=PfifoFast --simDuration=10", "True", "False"),
