@@ -19,10 +19,12 @@
  *          Sébastien Deronne <sebastien.deronne@gmail.com>
  */
 
-#include "spectrum-wifi-helper.h"
-#include "ns3/spectrum-wifi-phy.h"
-#include "ns3/names.h"
 #include "ns3/log.h"
+#include "ns3/names.h"
+#include "ns3/spectrum-wifi-phy.h"
+#include "ns3/error-rate-model.h"
+#include "ns3/mobility-model.h"
+#include "spectrum-wifi-helper.h"
 
 namespace ns3 {
 
