@@ -29,9 +29,9 @@
 
 namespace ns3 {
 
-class WifiPhy;
 class WifiNetDevice;
 class Node;
+class RadiotapHeader;
 
 /**
  * \brief create PHY objects
@@ -116,21 +116,22 @@ public:
    * called before EnablePcap(), so that the header of the pcap file can be
    * written correctly.
    *
-   * @see SupportedPcapDataLinkTypes
+   * \see SupportedPcapDataLinkTypes
    *
-   * @param dlt The data link type of the pcap file (and packets) to be used
+   * \param dlt The data link type of the pcap file (and packets) to be used
    */
   void SetPcapDataLinkType (SupportedPcapDataLinkTypes dlt);
 
   /**
    * Get the data link type of PCAP traces to be used.
    *
-   * @see SupportedPcapDataLinkTypes
+   * \see SupportedPcapDataLinkTypes
    *
-   * @returns The data link type of the pcap file (and packets) to be used
+   * \returns The data link type of the pcap file (and packets) to be used
    */
   PcapHelper::DataLinkType GetPcapDataLinkType (void) const;
 
+
 protected:
   /**
    * \param file the pcap file wrapper
@@ -166,17 +167,33 @@ protected:
   ObjectFactory m_phy; ///< PHY object
   ObjectFactory m_errorRateModel; ///< error rate model
 
+
 private:
   /**
-   * @brief Enable pcap output the indicated net device.
+   * Get the radiotap header.
+   *
+   * \param packet the packet
+   * \param channelFreqMhz the channel frequency
+   * \param txVector the TXVECTOR
+   * \param aMpdu the A-MPDU information
+   *
+   * \returns the radiotap header
+   */
+  static RadiotapHeader GetRadiotapHeader (Ptr<Packet> packet,
+                                           uint16_t channelFreqMhz,
+                                           WifiTxVector txVector,
+                                           MpduInfo aMpdu);
+
+  /**
+   * \brief Enable pcap output the indicated net device.
    *
    * NetDevice-specific implementation mechanism for hooking the trace and
    * writing to the trace file.
    *
-   * @param prefix Filename prefix to use for pcap files.
-   * @param nd Net device for which you want to enable tracing.
-   * @param promiscuous If true capture all possible packets available at the device.
-   * @param explicitFilename Treat the prefix as an explicit filename if true
+   * \param prefix Filename prefix to use for pcap files.
+   * \param nd Net device for which you want to enable tracing.
+   * \param promiscuous If true capture all possible packets available at the device.
+   * \param explicitFilename Treat the prefix as an explicit filename if true
    */
   virtual void EnablePcapInternal (std::string prefix,
                                    Ptr<NetDevice> nd,
@@ -265,9 +282,9 @@ public:
    */
   NetDeviceContainer
   virtual Install (const WifiPhyHelper &phy,
-                       const WifiMacHelper &mac,
-                       NodeContainer::Iterator first,
-                       NodeContainer::Iterator last) const;
+                   const WifiMacHelper &mac,
+                   NodeContainer::Iterator first,
+                   NodeContainer::Iterator last) const;
   /**
    * \param phy the PHY helper to create PHY objects
    * \param mac the MAC helper to create MAC objects
