@@ -20,13 +20,20 @@
  *          Mirko Banchi <mk.banchi@gmail.com>
  */
 
-#include "ap-wifi-mac.h"
 #include "ns3/log.h"
+#include "ns3/packet.h"
 #include "ns3/simulator.h"
-#include "ns3/string.h"
 #include "ns3/pointer.h"
+#include "ns3/string.h"
+#include "ns3/random-variable-stream.h"
+#include "ap-wifi-mac.h"
 #include "mac-low.h"
 #include "mac-tx-middle.h"
+#include "mac-rx-middle.h"
+#include "mgt-headers.h"
+#include "msdu-aggregator.h"
+#include "amsdu-subframe-header.h"
+#include "wifi-phy.h"
 
 namespace ns3 {
 
@@ -38,7 +45,7 @@ TypeId
 ApWifiMac::GetTypeId (void)
 {
   static TypeId tid = TypeId ("ns3::ApWifiMac")
-    .SetParent<RegularWifiMac> ()
+    .SetParent<InfrastructureWifiMac> ()
     .SetGroupName ("Wifi")
     .AddConstructor<ApWifiMac> ()
     .AddAttribute ("BeaconInterval",
@@ -47,6 +54,11 @@ ApWifiMac::GetTypeId (void)
                    MakeTimeAccessor (&ApWifiMac::GetBeaconInterval,
                                      &ApWifiMac::SetBeaconInterval),
                    MakeTimeChecker ())
+    .AddAttribute ("CfpMaxDuration", "The maximum size of the CFP (used when AP supports PCF)",
+                   TimeValue (MicroSeconds (51200)),
+                   MakeTimeAccessor (&ApWifiMac::GetCfpMaxDuration,
+                                     &ApWifiMac::SetCfpMaxDuration),
+                   MakeTimeChecker ())
     .AddAttribute ("BeaconJitter",
                    "A uniform random variable to cause the initial beacon starting time (after simulation time 0) "
                    "to be distributed between 0 and the BeaconInterval.",
@@ -61,8 +73,7 @@ ApWifiMac::GetTypeId (void)
     .AddAttribute ("BeaconGeneration",
                    "Whether or not beacons are generated.",
                    BooleanValue (true),
-                   MakeBooleanAccessor (&ApWifiMac::SetBeaconGeneration,
-                                        &ApWifiMac::GetBeaconGeneration),
+                   MakeBooleanAccessor (&ApWifiMac::SetBeaconGeneration),
                    MakeBooleanChecker ())
     .AddAttribute ("EnableNonErpProtection", "Whether or not protection mechanism should be used when non-ERP STAs are present within the BSS."
                    "This parameter is only used when ERP is supported by the AP.",
@@ -82,16 +93,20 @@ ApWifiMac::ApWifiMac ()
   : m_enableBeaconGeneration (false)
 {
   NS_LOG_FUNCTION (this);
-  m_beaconDca = CreateObject<DcaTxop> ();
-  m_beaconDca->SetAifsn (1);
-  m_beaconDca->SetMinCw (0);
-  m_beaconDca->SetMaxCw (0);
-  m_beaconDca->SetLow (m_low);
-  m_beaconDca->SetManager (m_dcfManager);
-  m_beaconDca->SetTxMiddle (m_txMiddle);
+  m_beaconTxop = CreateObject<Txop> ();
+  m_beaconTxop->SetAifsn (1);
+  m_beaconTxop->SetMinCw (0);
+  m_beaconTxop->SetMaxCw (0);
+  m_beaconTxop->SetMacLow (m_low);
+  m_beaconTxop->SetChannelAccessManager (m_channelAccessManager);
+  m_beaconTxop->SetTxMiddle (m_txMiddle);
+  m_beaconTxop->SetTxOkCallback (MakeCallback (&ApWifiMac::TxOk, this));
+  m_rxMiddle->SetPcfCallback (MakeCallback (&ApWifiMac::SendNextCfFrame, this));
 
   //Let the lower layers know that we are acting as an AP.
   SetTypeOfStation (AP);
+
+  m_itCfPollingList = m_cfPollingList.begin ();
 }
 
 ApWifiMac::~ApWifiMac ()
@@ -100,16 +115,18 @@ ApWifiMac::~ApWifiMac ()
   m_staList.clear ();
   m_nonErpStations.clear ();
   m_nonHtStations.clear ();
+  m_cfPollingList.clear ();
 }
 
 void
 ApWifiMac::DoDispose ()
 {
   NS_LOG_FUNCTION (this);
-  m_beaconDca->Dispose ();
-  m_beaconDca = 0;
+  m_beaconTxop->Dispose ();
+  m_beaconTxop = 0;
   m_enableBeaconGeneration = false;
   m_beaconEvent.Cancel ();
+  m_cfpEvent.Cancel ();
   RegularWifiMac::DoDispose ();
 }
 
@@ -138,26 +155,27 @@ ApWifiMac::SetBeaconGeneration (bool enable)
   m_enableBeaconGeneration = enable;
 }
 
-bool
-ApWifiMac::GetBeaconGeneration (void) const
-{
-  NS_LOG_FUNCTION (this);
-  return m_enableBeaconGeneration;
-}
-
 Time
 ApWifiMac::GetBeaconInterval (void) const
 {
   NS_LOG_FUNCTION (this);
-  return m_beaconInterval;
+  return m_low->GetBeaconInterval ();
+}
+
+Time
+ApWifiMac::GetCfpMaxDuration (void) const
+{
+  NS_LOG_FUNCTION (this);
+  return m_low->GetCfpMaxDuration ();
 }
 
 void
 ApWifiMac::SetWifiRemoteStationManager (const Ptr<WifiRemoteStationManager> stationManager)
 {
   NS_LOG_FUNCTION (this << stationManager);
-  m_beaconDca->SetWifiRemoteStationManager (stationManager);
+  m_beaconTxop->SetWifiRemoteStationManager (stationManager);
   RegularWifiMac::SetWifiRemoteStationManager (stationManager);
+  m_stationManager->SetPcfSupported (GetPcfSupported ());
 }
 
 void
@@ -180,7 +198,18 @@ ApWifiMac::SetBeaconInterval (Time interval)
     {
       NS_LOG_WARN ("beacon interval should be multiple of 1024us (802.11 time unit), see IEEE Std. 802.11-2012");
     }
-  m_beaconInterval = interval;
+  m_low->SetBeaconInterval (interval);
+}
+
+void
+ApWifiMac::SetCfpMaxDuration (Time duration)
+{
+  NS_LOG_FUNCTION (this << duration);
+  if ((duration.GetMicroSeconds () % 1024) != 0)
+    {
+      NS_LOG_WARN ("CFP max duration should be multiple of 1024us (802.11 time unit)");
+    }
+  m_low->SetCfpMaxDuration (duration);
 }
 
 int64_t
@@ -198,7 +227,7 @@ ApWifiMac::GetShortSlotTimeEnabled (void) const
     {
       return false;
     }
-  if (m_erpSupported == true && GetShortSlotTimeSupported () == true)
+  if (GetErpSupported () == true && GetShortSlotTimeSupported () == true)
     {
       for (std::map<uint16_t, Mac48Address>::const_iterator i = m_staList.begin (); i != m_staList.end (); i++)
         {
@@ -215,7 +244,7 @@ ApWifiMac::GetShortSlotTimeEnabled (void) const
 bool
 ApWifiMac::GetShortPreambleEnabled (void) const
 {
-  if (m_erpSupported || m_phy->GetShortPlcpPreambleSupported ())
+  if (GetErpSupported () || m_phy->GetShortPlcpPreambleSupported ())
     {
       for (std::list<Mac48Address>::const_iterator i = m_nonErpStations.begin (); i != m_nonErpStations.end (); i++)
         {
@@ -245,10 +274,10 @@ ApWifiMac::IsNonGfHtStasPresent (void) const
   return isNonGfHtStasPresent;
 }
 
-uint8_t
+uint16_t
 ApWifiMac::GetVhtOperationalChannelWidth (void) const
 {
-  uint8_t channelWidth = m_phy->GetChannelWidth ();
+  uint16_t channelWidth = m_phy->GetChannelWidth ();
   for (std::map<uint16_t, Mac48Address>::const_iterator i = m_staList.begin (); i != m_staList.end (); i++)
     {
       if (m_stationManager->GetVhtSupported (i->second))
@@ -273,7 +302,7 @@ ApWifiMac::ForwardDown (Ptr<const Packet> packet, Mac48Address from,
   uint8_t tid = 0;
 
   //If we are a QoS AP then we attempt to get a TID for this packet
-  if (m_qosSupported)
+  if (GetQosSupported ())
     {
       tid = QosUtilsGetTidForPacket (packet);
       //Any value greater than 7 is invalid and likely indicates that
@@ -300,7 +329,7 @@ ApWifiMac::ForwardDown (Ptr<const Packet> packet, Mac48Address from,
   //support simultaneously associated QoS and non-QoS STAs, at which
   //point there will need to be per-association QoS state maintained
   //by the association state machine, and consulted here.
-  if (m_qosSupported)
+  if (GetQosSupported ())
     {
       hdr.SetType (WIFI_MAC_QOSDATA);
       hdr.SetQosAckPolicy (WifiMacHeader::NORMAL_ACK);
@@ -316,9 +345,9 @@ ApWifiMac::ForwardDown (Ptr<const Packet> packet, Mac48Address from,
       hdr.SetType (WIFI_MAC_DATA);
     }
 
-  if (m_qosSupported || m_htSupported || m_vhtSupported || m_heSupported)
+  if (GetQosSupported () || GetHtSupported () || GetVhtSupported () || GetHeSupported ())
     {
-      hdr.SetNoOrder ();
+      hdr.SetNoOrder (); // explicitly set to 0 for the time being since HT/VHT/HE control field is not yet implemented (set it to 1 when implemented)
     }
   hdr.SetAddr1 (to);
   hdr.SetAddr2 (GetAddress ());
@@ -326,7 +355,7 @@ ApWifiMac::ForwardDown (Ptr<const Packet> packet, Mac48Address from,
   hdr.SetDsFrom ();
   hdr.SetDsNotTo ();
 
-  if (m_qosSupported)
+  if (GetQosSupported ())
     {
       //Sanity check that the TID is valid
       NS_ASSERT (tid < 8);
@@ -334,7 +363,7 @@ ApWifiMac::ForwardDown (Ptr<const Packet> packet, Mac48Address from,
     }
   else
     {
-      m_dca->Queue (packet, hdr);
+      m_txop->Queue (packet, hdr);
     }
 }
 
@@ -374,18 +403,6 @@ ApWifiMac::GetSupportedRates (void) const
 {
   NS_LOG_FUNCTION (this);
   SupportedRates rates;
-  //If it is an HT-AP or VHT-AP or HE-AP, then add the BSSMembershipSelectorSet
-  //The standard says that the BSSMembershipSelectorSet
-  //must have its MSB set to 1 (must be treated as a Basic Rate)
-  //Also the standard mentioned that at least 1 element should be included in the SupportedRates the rest can be in the ExtendedSupportedRates
-  if (m_htSupported || m_vhtSupported || m_heSupported)
-    {
-      for (uint8_t i = 0; i < m_phy->GetNBssMembershipSelectors (); i++)
-        {
-          rates.AddBssMembershipSelectorRate (m_phy->GetBssMembershipSelector (i));
-        }
-    }
-  //
   //Send the set of supported rates and make sure that we indicate
   //the Basic Rate set in this set of supported rates.
   for (uint8_t i = 0; i < m_phy->GetNModes (); i++)
@@ -411,7 +428,17 @@ ApWifiMac::GetSupportedRates (void) const
       NS_LOG_DEBUG ("Setting basic rate " << mode.GetUniqueName ());
       rates.SetBasicRate (modeDataRate);
     }
-
+  //If it is an HT-AP or VHT-AP or HE-AP, then add the BSSMembershipSelectorSet
+  //The standard says that the BSSMembershipSelectorSet
+  //must have its MSB set to 1 (must be treated as a Basic Rate)
+  //Also the standard mentioned that at least 1 element should be included in the SupportedRates the rest can be in the ExtendedSupportedRates
+  if (GetHtSupported () || GetVhtSupported () || GetHeSupported ())
+    {
+      for (uint8_t i = 0; i < m_phy->GetNBssMembershipSelectors (); i++)
+        {
+          rates.AddBssMembershipSelectorRate (m_phy->GetBssMembershipSelector (i));
+        }
+    }
   return rates;
 }
 
@@ -420,7 +447,7 @@ ApWifiMac::GetDsssParameterSet (void) const
 {
   NS_LOG_FUNCTION (this);
   DsssParameterSet dsssParameters;
-  if (m_dsssSupported)
+  if (GetDsssSupported ())
     {
       dsssParameters.SetDsssSupported (1);
       dsssParameters.SetCurrentChannel (m_phy->GetChannelNumber ());
@@ -436,6 +463,10 @@ ApWifiMac::GetCapabilities (void) const
   capabilities.SetShortPreamble (GetShortPreambleEnabled ());
   capabilities.SetShortSlotTime (GetShortSlotTimeEnabled ());
   capabilities.SetEss ();
+  if (GetPcfSupported ())
+    {
+      capabilities.SetCfPollable ();
+    }
   return capabilities;
 }
 
@@ -445,7 +476,7 @@ ApWifiMac::GetErpInformation (void) const
   NS_LOG_FUNCTION (this);
   ErpInformation information;
   information.SetErpSupported (1);
-  if (m_erpSupported)
+  if (GetErpSupported ())
     {
       information.SetNonErpPresent (!m_nonErpStations.empty ());
       information.SetUseProtection (GetUseNonErpProtection ());
@@ -466,10 +497,10 @@ ApWifiMac::GetEdcaParameterSet (void) const
 {
   NS_LOG_FUNCTION (this);
   EdcaParameterSet edcaParameters;
-  if (m_qosSupported)
+  if (GetQosSupported ())
     {
       edcaParameters.SetQosSupported (1);
-      Ptr<EdcaTxopN> edca;
+      Ptr<QosTxop> edca;
       Time txopLimit;
 
       edca = m_edca.find (AC_BE)->second;
@@ -478,8 +509,7 @@ ApWifiMac::GetEdcaParameterSet (void) const
       edcaParameters.SetBeCWmin (edca->GetMinCw ());
       edcaParameters.SetBeCWmax (edca->GetMaxCw ());
       edcaParameters.SetBeAifsn (edca->GetAifsn ());
-      edcaParameters.SetBeTXOPLimit (txopLimit.GetMicroSeconds () / 32);
-      edcaParameters.SetBeAcm (0);
+      edcaParameters.SetBeTxopLimit (static_cast<uint16_t> (txopLimit.GetMicroSeconds () / 32));
 
       edca = m_edca.find (AC_BK)->second;
       txopLimit = edca->GetTxopLimit ();
@@ -487,8 +517,7 @@ ApWifiMac::GetEdcaParameterSet (void) const
       edcaParameters.SetBkCWmin (edca->GetMinCw ());
       edcaParameters.SetBkCWmax (edca->GetMaxCw ());
       edcaParameters.SetBkAifsn (edca->GetAifsn ());
-      edcaParameters.SetBkTXOPLimit (txopLimit.GetMicroSeconds () / 32);
-      edcaParameters.SetBkAcm (0);
+      edcaParameters.SetBkTxopLimit (static_cast<uint16_t> (txopLimit.GetMicroSeconds () / 32));
 
       edca = m_edca.find (AC_VI)->second;
       txopLimit = edca->GetTxopLimit ();
@@ -496,8 +525,7 @@ ApWifiMac::GetEdcaParameterSet (void) const
       edcaParameters.SetViCWmin (edca->GetMinCw ());
       edcaParameters.SetViCWmax (edca->GetMaxCw ());
       edcaParameters.SetViAifsn (edca->GetAifsn ());
-      edcaParameters.SetViTXOPLimit (txopLimit.GetMicroSeconds () / 32);
-      edcaParameters.SetViAcm (0);
+      edcaParameters.SetViTxopLimit (static_cast<uint16_t> (txopLimit.GetMicroSeconds () / 32));
 
       edca = m_edca.find (AC_VO)->second;
       txopLimit = edca->GetTxopLimit ();
@@ -505,22 +533,37 @@ ApWifiMac::GetEdcaParameterSet (void) const
       edcaParameters.SetVoCWmin (edca->GetMinCw ());
       edcaParameters.SetVoCWmax (edca->GetMaxCw ());
       edcaParameters.SetVoAifsn (edca->GetAifsn ());
-      edcaParameters.SetVoTXOPLimit (txopLimit.GetMicroSeconds () / 32);
-      edcaParameters.SetVoAcm (0);
+      edcaParameters.SetVoTxopLimit (static_cast<uint16_t> (txopLimit.GetMicroSeconds () / 32));
 
       edcaParameters.SetQosInfo (0);
     }
   return edcaParameters;
 }
 
+CfParameterSet
+ApWifiMac::GetCfParameterSet (void) const
+{
+  CfParameterSet cfParameterSet;
+  if (GetPcfSupported () && !m_cfPollingList.empty ())
+    {
+      cfParameterSet.SetPcfSupported (1);
+      cfParameterSet.SetCFPCount (0);
+      cfParameterSet.SetCFPPeriod (1);
+      cfParameterSet.SetCFPMaxDurationUs (GetCfpMaxDuration ().GetMicroSeconds ());
+      cfParameterSet.SetCFPDurRemainingUs (GetCfpMaxDuration ().GetMicroSeconds ());
+    }
+  return cfParameterSet;
+}
+
 HtOperation
 ApWifiMac::GetHtOperation (void) const
 {
   NS_LOG_FUNCTION (this);
   HtOperation operation;
-  if (m_htSupported)
+  if (GetHtSupported ())
     {
       operation.SetHtSupported (1);
+      operation.SetPrimaryChannel (m_phy->GetChannelNumber ());
       operation.SetRifsMode (GetRifsMode ());
       operation.SetNonGfHtStasPresent (IsNonGfHtStasPresent ());
       if (m_phy->GetChannelWidth () > 20)
@@ -589,7 +632,7 @@ ApWifiMac::GetHtOperation (void) const
                 }
             }
         }
-      operation.SetRxHighestSupportedDataRate (maxSupportedRate / 1e6); //in Mbit/s
+      operation.SetRxHighestSupportedDataRate (static_cast<uint16_t> (maxSupportedRate / 1e6)); //in Mbit/s
       operation.SetTxMcsSetDefined (nMcs > 0);
       operation.SetTxMaxNSpatialStreams (maxSpatialStream);
       //To be filled in once supported
@@ -612,10 +655,10 @@ ApWifiMac::GetVhtOperation (void) const
 {
   NS_LOG_FUNCTION (this);
   VhtOperation operation;
-  if (m_vhtSupported)
+  if (GetVhtSupported ())
     {
       operation.SetVhtSupported (1);
-      uint8_t channelWidth = GetVhtOperationalChannelWidth ();
+      uint16_t channelWidth = GetVhtOperationalChannelWidth ();
       if (channelWidth == 160)
         {
           operation.SetChannelWidth (2);
@@ -650,7 +693,7 @@ ApWifiMac::GetHeOperation (void) const
 {
   NS_LOG_FUNCTION (this);
   HeOperation operation;
-  if (m_heSupported)
+  if (GetHeSupported ())
     {
       operation.SetHeSupported (1);
       for (uint8_t nss = 1; nss <= m_phy->GetMaxSupportedRxSpatialStreams (); nss++)
@@ -672,39 +715,38 @@ ApWifiMac::SendProbeResp (Mac48Address to)
   hdr.SetAddr3 (GetAddress ());
   hdr.SetDsNotFrom ();
   hdr.SetDsNotTo ();
-  hdr.SetNoOrder ();
   Ptr<Packet> packet = Create<Packet> ();
   MgtProbeResponseHeader probe;
   probe.SetSsid (GetSsid ());
   probe.SetSupportedRates (GetSupportedRates ());
-  probe.SetBeaconIntervalUs (m_beaconInterval.GetMicroSeconds ());
+  probe.SetBeaconIntervalUs (GetBeaconInterval ().GetMicroSeconds ());
   probe.SetCapabilities (GetCapabilities ());
   m_stationManager->SetShortPreambleEnabled (GetShortPreambleEnabled ());
   m_stationManager->SetShortSlotTimeEnabled (GetShortSlotTimeEnabled ());
-  if (m_dsssSupported)
+  if (GetDsssSupported ())
     {
       probe.SetDsssParameterSet (GetDsssParameterSet ());
     }
-  if (m_erpSupported)
+  if (GetErpSupported ())
     {
       probe.SetErpInformation (GetErpInformation ());
     }
-  if (m_qosSupported)
+  if (GetQosSupported ())
     {
       probe.SetEdcaParameterSet (GetEdcaParameterSet ());
     }
-  if (m_htSupported || m_vhtSupported || m_heSupported)
+  if (GetHtSupported () || GetVhtSupported () || GetHeSupported ())
     {
       probe.SetExtendedCapabilities (GetExtendedCapabilities ());
       probe.SetHtCapabilities (GetHtCapabilities ());
       probe.SetHtOperation (GetHtOperation ());
     }
-  if (m_vhtSupported || m_heSupported)
+  if (GetVhtSupported () || GetHeSupported ())
     {
       probe.SetVhtCapabilities (GetVhtCapabilities ());
       probe.SetVhtOperation (GetVhtOperation ());
     }
-  if (m_heSupported)
+  if (GetHeSupported ())
     {
       probe.SetHeCapabilities (GetHeCapabilities ());
       probe.SetHeOperation (GetHeOperation ());
@@ -715,7 +757,7 @@ ApWifiMac::SendProbeResp (Mac48Address to)
   //frames if we are a QoS AP. The approach taken here is to always
   //use the DCF for these regardless of whether we have a QoS
   //association or not.
-  m_dca->Queue (packet, hdr);
+  m_txop->Queue (packet, hdr);
 }
 
 void
@@ -729,14 +771,13 @@ ApWifiMac::SendAssocResp (Mac48Address to, bool success, bool isReassoc)
   hdr.SetAddr3 (GetAddress ());
   hdr.SetDsNotFrom ();
   hdr.SetDsNotTo ();
-  hdr.SetNoOrder ();
   Ptr<Packet> packet = Create<Packet> ();
   MgtAssocResponseHeader assoc;
   StatusCode code;
   if (success)
     {
       code.SetSuccess ();
-      uint16_t aid;
+      uint16_t aid = 0;
       bool found = false;
       if (isReassoc)
         {
@@ -764,26 +805,26 @@ ApWifiMac::SendAssocResp (Mac48Address to, bool success, bool isReassoc)
   assoc.SetSupportedRates (GetSupportedRates ());
   assoc.SetStatusCode (code);
   assoc.SetCapabilities (GetCapabilities ());
-  if (m_erpSupported)
+  if (GetErpSupported ())
     {
       assoc.SetErpInformation (GetErpInformation ());
     }
-  if (m_qosSupported)
+  if (GetQosSupported ())
     {
       assoc.SetEdcaParameterSet (GetEdcaParameterSet ());
     }
-  if (m_htSupported || m_vhtSupported || m_heSupported)
+  if (GetHtSupported () || GetVhtSupported () || GetHeSupported ())
     {
       assoc.SetExtendedCapabilities (GetExtendedCapabilities ());
       assoc.SetHtCapabilities (GetHtCapabilities ());
       assoc.SetHtOperation (GetHtOperation ());
     }
-  if (m_vhtSupported || m_heSupported)
+  if (GetVhtSupported () || GetHeSupported ())
     {
       assoc.SetVhtCapabilities (GetVhtCapabilities ());
       assoc.SetVhtOperation (GetVhtOperation ());
     }
-  if (m_heSupported)
+  if (GetHeSupported ())
     {
       assoc.SetHeCapabilities (GetHeCapabilities ());
       assoc.SetHeOperation (GetHeOperation ());
@@ -794,7 +835,7 @@ ApWifiMac::SendAssocResp (Mac48Address to, bool success, bool isReassoc)
   //frames if we are a QoS AP. The approach taken here is to always
   //use the DCF for these regardless of whether we have a QoS
   //association or not.
-  m_dca->Queue (packet, hdr);
+  m_txop->Queue (packet, hdr);
 }
 
 void
@@ -808,39 +849,42 @@ ApWifiMac::SendOneBeacon (void)
   hdr.SetAddr3 (GetAddress ());
   hdr.SetDsNotFrom ();
   hdr.SetDsNotTo ();
-  hdr.SetNoOrder ();
   Ptr<Packet> packet = Create<Packet> ();
   MgtBeaconHeader beacon;
   beacon.SetSsid (GetSsid ());
   beacon.SetSupportedRates (GetSupportedRates ());
-  beacon.SetBeaconIntervalUs (m_beaconInterval.GetMicroSeconds ());
+  beacon.SetBeaconIntervalUs (GetBeaconInterval ().GetMicroSeconds ());
   beacon.SetCapabilities (GetCapabilities ());
   m_stationManager->SetShortPreambleEnabled (GetShortPreambleEnabled ());
   m_stationManager->SetShortSlotTimeEnabled (GetShortSlotTimeEnabled ());
-  if (m_dsssSupported)
+  if (GetPcfSupported ())
+    {
+      beacon.SetCfParameterSet (GetCfParameterSet ());
+    }
+  if (GetDsssSupported ())
     {
       beacon.SetDsssParameterSet (GetDsssParameterSet ());
     }
-  if (m_erpSupported)
+  if (GetErpSupported ())
     {
       beacon.SetErpInformation (GetErpInformation ());
     }
-  if (m_qosSupported)
+  if (GetQosSupported ())
     {
       beacon.SetEdcaParameterSet (GetEdcaParameterSet ());
     }
-  if (m_htSupported || m_vhtSupported)
+  if (GetHtSupported () || GetVhtSupported ())
     {
       beacon.SetExtendedCapabilities (GetExtendedCapabilities ());
       beacon.SetHtCapabilities (GetHtCapabilities ());
       beacon.SetHtOperation (GetHtOperation ());
     }
-  if (m_vhtSupported || m_heSupported)
+  if (GetVhtSupported () || GetHeSupported ())
     {
       beacon.SetVhtCapabilities (GetVhtCapabilities ());
       beacon.SetVhtOperation (GetVhtOperation ());
     }
-  if (m_heSupported)
+  if (GetHeSupported ())
     {
       beacon.SetHeCapabilities (GetHeCapabilities ());
       beacon.SetHeOperation (GetHeOperation ());
@@ -848,13 +892,13 @@ ApWifiMac::SendOneBeacon (void)
   packet->AddHeader (beacon);
 
   //The beacon has it's own special queue, so we load it in there
-  m_beaconDca->Queue (packet, hdr);
-  m_beaconEvent = Simulator::Schedule (m_beaconInterval, &ApWifiMac::SendOneBeacon, this);
+  m_beaconTxop->Queue (packet, hdr);
+  m_beaconEvent = Simulator::Schedule (GetBeaconInterval (), &ApWifiMac::SendOneBeacon, this);
 
   //If a STA that does not support Short Slot Time associates,
   //the AP shall use long slot time beginning at the first Beacon
   //subsequent to the association of the long slot time STA.
-  if (m_erpSupported)
+  if (GetErpSupported ())
     {
       if (GetShortSlotTimeEnabled () == true)
         {
@@ -869,6 +913,39 @@ ApWifiMac::SendOneBeacon (void)
     }
 }
 
+void
+ApWifiMac::SendNextCfFrame (void)
+{
+  if (!GetPcfSupported ())
+    {
+      return;
+    }
+  if (m_txop->CanStartNextPolling ())
+    {
+      SendCfPoll ();
+    }
+  else if (m_low->IsCfPeriod ())
+    {
+      SendCfEnd ();
+    }
+}
+
+void
+ApWifiMac::SendCfPoll (void)
+{
+  NS_LOG_FUNCTION (this);
+  NS_ASSERT (GetPcfSupported ());
+  m_txop->SendCfFrame (WIFI_MAC_DATA_NULL_CFPOLL, *m_itCfPollingList);
+}
+
+void
+ApWifiMac::SendCfEnd (void)
+{
+  NS_LOG_FUNCTION (this);
+  NS_ASSERT (GetPcfSupported ());
+  m_txop->SendCfFrame (WIFI_MAC_CTL_END, Mac48Address::GetBroadcast ());
+}
+
 void
 ApWifiMac::TxOk (const WifiMacHeader &hdr)
 {
@@ -880,6 +957,21 @@ ApWifiMac::TxOk (const WifiMacHeader &hdr)
       NS_LOG_DEBUG ("associated with sta=" << hdr.GetAddr1 ());
       m_stationManager->RecordGotAssocTxOk (hdr.GetAddr1 ());
     }
+  else if (hdr.IsBeacon () && GetPcfSupported ())
+    {
+      if (!m_cfPollingList.empty ())
+        {
+          SendCfPoll ();
+        }
+      else
+        {
+          SendCfEnd ();
+        }
+    }
+  else if (hdr.IsCfPoll ())
+    {
+      IncrementPollingListIterator ();
+    }
 }
 
 void
@@ -894,6 +986,11 @@ ApWifiMac::TxFailed (const WifiMacHeader &hdr)
       NS_LOG_DEBUG ("association failed with sta=" << hdr.GetAddr1 ());
       m_stationManager->RecordGotAssocTxFailed (hdr.GetAddr1 ());
     }
+  else if (hdr.IsCfPoll ())
+    {
+      IncrementPollingListIterator ();
+      SendNextCfFrame ();
+    }
 }
 
 void
@@ -926,7 +1023,7 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                       ForwardUp (packet, from, bssid);
                     }
                 }
-              else
+              else if (hdr->HasData ())
                 {
                   ForwardUp (packet, from, bssid);
                 }
@@ -1036,7 +1133,7 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                     }
                 }
               m_stationManager->AddSupportedErpSlotTime (from, capabilities.IsShortSlotTime () && isErpStation);
-              if (m_htSupported)
+              if (GetHtSupported ())
                 {
                   //check whether the HT STA supports all MCSs in Basic MCS Set
                   HtCapabilities htcapabilities = assocReq.GetHtCapabilities ();
@@ -1054,7 +1151,7 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                         }
                     }
                 }
-              if (m_vhtSupported)
+              if (GetVhtSupported ())
                 {
                   //check whether the VHT STA supports all MCSs in Basic MCS Set
                   VhtCapabilities vhtcapabilities = assocReq.GetVhtCapabilities ();
@@ -1071,7 +1168,7 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                         }
                     }
                 }
-              if (m_heSupported)
+              if (GetHeSupported ())
                 {
                   //check whether the HE STA supports all MCSs in Basic MCS Set
                   HeCapabilities hecapabilities = assocReq.GetHeCapabilities ();
@@ -1105,7 +1202,15 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                           m_stationManager->AddSupportedMode (from, mode);
                         }
                     }
-                  if (m_htSupported)
+                  if (GetPcfSupported () && capabilities.IsCfPollable ())
+                    {
+                      m_cfPollingList.push_back (from);
+                      if (m_itCfPollingList == m_cfPollingList.end ())
+                        {
+                          IncrementPollingListIterator ();
+                        }
+                    }
+                  if (GetHtSupported ())
                     {
                       HtCapabilities htCapabilities = assocReq.GetHtCapabilities ();
                       if (htCapabilities.IsSupportedMcs (0))
@@ -1113,7 +1218,7 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                           m_stationManager->AddStationHtCapabilities (from, htCapabilities);
                         }
                     }
-                  if (m_vhtSupported)
+                  if (GetVhtSupported ())
                     {
                       VhtCapabilities vhtCapabilities = assocReq.GetVhtCapabilities ();
                       //we will always fill in RxHighestSupportedLgiDataRate field at TX, so this can be used to check whether it supports VHT
@@ -1131,12 +1236,12 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                             }
                         }
                     }
-                  if (m_htSupported || m_vhtSupported)
+                  if (GetHtSupported () || GetVhtSupported ())
                     {
                       ExtendedCapabilities extendedCapabilities = assocReq.GetExtendedCapabilities ();
                       //TODO: to be completed
                     }
-                  if (m_heSupported)
+                  if (GetHeSupported ())
                     {
                       HeCapabilities heCapabilities = assocReq.GetHeCapabilities ();
                       //todo: once we support non constant rate managers, we should add checks here whether HE is supported by the peer
@@ -1222,7 +1327,7 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                     }
                 }
               m_stationManager->AddSupportedErpSlotTime (from, capabilities.IsShortSlotTime () && isErpStation);
-              if (m_htSupported)
+              if (GetHtSupported ())
                 {
                   //check whether the HT STA supports all MCSs in Basic MCS Set
                   HtCapabilities htcapabilities = reassocReq.GetHtCapabilities ();
@@ -1240,7 +1345,7 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                         }
                     }
                 }
-              if (m_vhtSupported)
+              if (GetVhtSupported ())
                 {
                   //check whether the VHT STA supports all MCSs in Basic MCS Set
                   VhtCapabilities vhtcapabilities = reassocReq.GetVhtCapabilities ();
@@ -1257,7 +1362,7 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                         }
                     }
                 }
-              if (m_heSupported)
+              if (GetHeSupported ())
                 {
                   //check whether the HE STA supports all MCSs in Basic MCS Set
                   HeCapabilities hecapabilities = reassocReq.GetHeCapabilities ();
@@ -1291,7 +1396,7 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                           m_stationManager->AddSupportedMode (from, mode);
                         }
                     }
-                  if (m_htSupported)
+                  if (GetHtSupported ())
                     {
                       HtCapabilities htCapabilities = reassocReq.GetHtCapabilities ();
                       if (htCapabilities.IsSupportedMcs (0))
@@ -1299,7 +1404,7 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                           m_stationManager->AddStationHtCapabilities (from, htCapabilities);
                         }
                     }
-                  if (m_vhtSupported)
+                  if (GetVhtSupported ())
                     {
                       VhtCapabilities vhtCapabilities = reassocReq.GetVhtCapabilities ();
                       //we will always fill in RxHighestSupportedLgiDataRate field at TX, so this can be used to check whether it supports VHT
@@ -1317,12 +1422,12 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                             }
                         }
                     }
-                  if (m_htSupported || m_vhtSupported)
+                  if (GetHtSupported () || GetVhtSupported ())
                     {
                       ExtendedCapabilities extendedCapabilities = reassocReq.GetExtendedCapabilities ();
                       //TODO: to be completed
                     }
-                  if (m_heSupported)
+                  if (GetHeSupported ())
                     {
                       HeCapabilities heCapabilities = reassocReq.GetHeCapabilities ();
                       //todo: once we support non constant rate managers, we should add checks here whether HE is supported by the peer
@@ -1381,6 +1486,14 @@ ApWifiMac::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                       break;
                     }
                 }
+              for (std::list<Mac48Address>::const_iterator j = m_cfPollingList.begin (); j != m_cfPollingList.end (); ++j)
+                {
+                  if ((*j) == from)
+                    {
+                      m_cfPollingList.erase (j);
+                      break;
+                    }
+                }
               return;
             }
         }
@@ -1419,15 +1532,15 @@ void
 ApWifiMac::DoInitialize (void)
 {
   NS_LOG_FUNCTION (this);
-  m_beaconDca->Initialize ();
+  m_beaconTxop->Initialize ();
   m_beaconEvent.Cancel ();
   if (m_enableBeaconGeneration)
     {
       if (m_enableBeaconJitter)
         {
-          int64_t jitter = m_beaconJitter->GetValue (0, m_beaconInterval.GetMicroSeconds ());
-          NS_LOG_DEBUG ("Scheduling initial beacon for access point " << GetAddress () << " at time " << jitter << " microseconds");
-          m_beaconEvent = Simulator::Schedule (MicroSeconds (jitter), &ApWifiMac::SendOneBeacon, this);
+          Time jitter = MicroSeconds (static_cast<int64_t> (m_beaconJitter->GetValue (0, 1) * (GetBeaconInterval ().GetMicroSeconds ())));
+          NS_LOG_DEBUG ("Scheduling initial beacon for access point " << GetAddress () << " at time " << jitter);
+          m_beaconEvent = Simulator::Schedule (jitter, &ApWifiMac::SendOneBeacon, this);
         }
       else
         {
@@ -1450,7 +1563,7 @@ bool
 ApWifiMac::GetRifsMode (void) const
 {
   bool rifsMode = false;
-  if (m_htSupported && !m_vhtSupported) //RIFS mode is forbidden for VHT
+  if (GetHtSupported () && !GetVhtSupported ()) //RIFS mode is forbidden for VHT
     {
       if (m_nonHtStations.empty () || !m_disableRifs)
         {
@@ -1479,8 +1592,19 @@ ApWifiMac::GetNextAssociationId (void)
           return nextAid;
         }
     }
-  NS_ASSERT_MSG (false, "No free association ID available!");
+  NS_FATAL_ERROR ("No free association ID available!");
   return 0;
 }
 
+void
+ApWifiMac::IncrementPollingListIterator (void)
+{
+  NS_LOG_FUNCTION (this);
+  m_itCfPollingList++;
+  if (m_itCfPollingList == m_cfPollingList.end ())
+    {
+      m_itCfPollingList = m_cfPollingList.begin ();
+    }
+}
+
 } //namespace ns3
