@@ -21,19 +21,22 @@
 #ifndef BLOCK_ACK_MANAGER_H
 #define BLOCK_ACK_MANAGER_H
 
+#include <map>
+#include "ns3/nstime.h"
 #include "wifi-mac-header.h"
 #include "originator-block-ack-agreement.h"
-#include "ctrl-headers.h"
-#include "qos-utils.h"
-#include "wifi-remote-station-manager.h"
-#include <map>
+#include "block-ack-type.h"
 
 namespace ns3 {
 
+class WifiRemoteStationManager;
 class MgtAddBaResponseHeader;
 class MgtAddBaRequestHeader;
+class CtrlBAckResponseHeader;
 class MacTxMiddle;
 class WifiMacQueue;
+class WifiMode;
+class Packet;
 
 /**
  * \ingroup wifi
@@ -184,7 +187,7 @@ public:
    * \param dataSnr data SNR reported by remote station
    *
    * Invoked upon receipt of a block ack frame. Typically, this function, is called
-   * by ns3::EdcaTxopN object. Performs a check on which MPDUs, previously sent
+   * by ns3::QosTxop object. Performs a check on which MPDUs, previously sent
    * with ack policy set to Block Ack, were correctly received by the recipient.
    * An acknowledged MPDU is removed from the buffer, retransmitted otherwise.
    */
@@ -230,10 +233,10 @@ public:
   /**
    * \param recipient Address of peer station involved in block ack mechanism.
    * \param tid Traffic ID of transmitted packet.
-   * \param nextSeqNumber Sequence number of the next packet that would be trasmitted by EdcaTxopN.
+   * \param nextSeqNumber Sequence number of the next packet that would be trasmitted by QosTxop.
    * \param policy ack policy of the transmitted packet.
    *
-   * This method is typically invoked by ns3::EdcaTxopN object every time that a MPDU
+   * This method is typically invoked by ns3::QosTxop object every time that a MPDU
    * with ack policy subfield in Qos Control field set to Block Ack is transmitted.
    * The <i>nextSeqNumber</i> parameter is used to block transmission of packets that are out of bitmap.
    */
@@ -242,7 +245,7 @@ public:
    * \param recipient Address of peer station involved in block ack mechanism.
    * \param tid Traffic ID of transmitted packet.
    *
-   * This method to set the number of packets waitin for blockAck = 0 since the receiver will send the blockAck right away
+   * This method to set the number of packets waiting for blockAck = 0 since the receiver will send the blockAck right away
    */
   void CompleteAmpduExchange (Mac48Address recipient, uint8_t tid);
   /**
@@ -341,13 +344,12 @@ public:
    * This method doesn't remove the packet from this queue.
    *
    * \param hdr wifi mac header
-   * \param recipient mac address
    * \param tid Traffic ID
    * \param timestamp timestamp
    *
    * \returns Ptr<const Packet>
    */
-  Ptr<const Packet> PeekNextPacketByTidAndAddress (WifiMacHeader &hdr, Mac48Address recipient, uint8_t tid, Time *timestamp);
+  Ptr<const Packet> PeekNextPacketByTidAndAddress (WifiMacHeader &hdr, uint8_t tid, Time *timestamp);
   /**
    * This function returns true if the lifetime of the packets a BAR refers to didn't expire yet else it returns false.
    * If it return false then the BAR will be discarded (i.e. will not be re-transmitted)
@@ -490,8 +492,8 @@ private:
   std::list<PacketQueueI> m_retryPackets;
   std::list<Bar> m_bars; ///< list of BARs
 
-  uint8_t m_blockAckThreshold; ///< bock ack threshold
-  BlockAckType m_blockAckType; ///< bock ack type
+  uint8_t m_blockAckThreshold; ///< block ack threshold
+  BlockAckType m_blockAckType; ///< block ack type
   Time m_maxDelay; ///< maximum delay
   Ptr<MacTxMiddle> m_txMiddle; ///< the MacTxMiddle
   Mac48Address m_address; ///< address
