@@ -21,7 +21,6 @@
 #ifndef HE_CAPABILITIES_H
 #define HE_CAPABILITIES_H
 
-#include "ns3/buffer.h"
 #include "wifi-information-element.h"
 
 namespace ns3 {
@@ -64,17 +63,17 @@ public:
   uint8_t DeserializeInformationField (Buffer::Iterator start, uint8_t length);
 
   /**
-   * Set the HE MAC Capabilties Info field in the HE Capabilities information element.
+   * Set the HE MAC Capabilities Info field in the HE Capabilities information element.
    *
-   * \param ctrl1 the HE MAC Capabilties Info field 1 in the HE Capabilities information element
-   * \param ctrl2 the HE MAC Capabilties Info field 2 in the HE Capabilities information element
+   * \param ctrl1 the HE MAC Capabilities Info field 1 in the HE Capabilities information element
+   * \param ctrl2 the HE MAC Capabilities Info field 2 in the HE Capabilities information element
    */
   void SetHeMacCapabilitiesInfo (uint32_t ctrl1, uint8_t ctrl2);
   /**
-   * Set the HE PHY Capabilties Info field in the HE Capabilities information element.
+   * Set the HE PHY Capabilities Info field in the HE Capabilities information element.
    *
-   * \param ctrl1 the HE PHY Capabilties Info field 1 in the HE Capabilities information element
-   * \param ctrl2 the HE PHY Capabilties Info field 2 in the HE Capabilities information element
+   * \param ctrl1 the HE PHY Capabilities Info field 1 in the HE Capabilities information element
+   * \param ctrl2 the HE PHY Capabilities Info field 2 in the HE Capabilities information element
    */
   void SetHePhyCapabilitiesInfo (uint64_t ctrl1, uint8_t ctrl2);
   /**
@@ -85,27 +84,27 @@ public:
   void SetSupportedMcsAndNss (uint16_t ctrl);
 
   /**
-   * Return the 4 first octets of the HE MAC Capabilties Info field in the HE Capabilities information element.
+   * Return the 4 first octets of the HE MAC Capabilities Info field in the HE Capabilities information element.
    *
-   * \return the 4 first octets of the HE MAC Capabilties Info field in the HE Capabilities information element
+   * \return the 4 first octets of the HE MAC Capabilities Info field in the HE Capabilities information element
    */
   uint32_t GetHeMacCapabilitiesInfo1 () const;
   /**
-   * Return the last octet of the HE MAC Capabilties Info field in the HE Capabilities information element.
+   * Return the last octet of the HE MAC Capabilities Info field in the HE Capabilities information element.
    *
-   * \return the last octet of the HE MAC Capabilties Info field in the HE Capabilities information element
+   * \return the last octet of the HE MAC Capabilities Info field in the HE Capabilities information element
    */
   uint8_t GetHeMacCapabilitiesInfo2 () const;
   /**
-   * Return the 8 first octets of the HE PHY Capabilties Info field in the HE Capabilities information element.
+   * Return the 8 first octets of the HE PHY Capabilities Info field in the HE Capabilities information element.
    *
-   * \return the 8 first octets of the HE PHY Capabilties Info field in the HE Capabilities information element
+   * \return the 8 first octets of the HE PHY Capabilities Info field in the HE Capabilities information element
    */
   uint64_t GetHePhyCapabilitiesInfo1 () const;
   /**
-   * Return the last octet of the HE PHY Capabilties Info field in the HE Capabilities information element.
+   * Return the last octet of the HE PHY Capabilities Info field in the HE Capabilities information element.
    *
-   * \return the last octet of the HE PHY Capabilties Info field in the HE Capabilities information element
+   * \return the last octet of the HE PHY Capabilities Info field in the HE Capabilities information element
    */
   uint8_t GetHePhyCapabilitiesInfo2 () const;
   /**
@@ -229,7 +228,7 @@ private:
   uint8_t m_broadcastTwtSupport; //!< broadcast TXT support
   uint8_t m_32bitBaBitmapSupport; //!< 32bit BA bitmap support
   uint8_t m_muCascadeSupport; //!< MU cascade support
-  uint8_t m_ackEnabledMultiTidAggregationSupport; //!< ack enabled multi TID aggregation suport
+  uint8_t m_ackEnabledMultiTidAggregationSupport; //!< ack enabled multi TID aggregation support
   uint8_t m_groupAddressedMultiStaBlockAckInDlMuSupport; //!< group addressed multi STA block ack in DL support
   uint8_t m_omiAcontrolSupport; //!< OMI A control support
   uint8_t m_ofdmaRaSupport; //!< OFDM RA support
@@ -287,9 +286,6 @@ private:
 };
 
 std::ostream &operator << (std::ostream &os, const HeCapabilities &HeCapabilities);
-std::istream &operator >> (std::istream &is, HeCapabilities &HeCapabilities);
-
-ATTRIBUTE_HELPER_HEADER (HeCapabilities);
 
 } //namespace ns3
 
