@@ -18,10 +18,11 @@
  * Author: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  */
 
-#include "mac-rx-middle.h"
-#include "wifi-mac-header.h"
 #include "ns3/log.h"
 #include "ns3/sequence-number.h"
+#include "ns3/packet.h"
+#include "mac-rx-middle.h"
+#include "wifi-mac-header.h"
 
 namespace ns3 {
 
@@ -299,9 +300,13 @@ MacRxMiddle::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
 {
   NS_LOG_FUNCTION (packet << hdr);
   NS_ASSERT (hdr->IsData () || hdr->IsMgt ());
+  if (!m_pcfCallback.IsNull ())
+    {
+      m_pcfCallback ();
+    }
   OriginatorRxStatus *originator = Lookup (hdr);
   /**
-   * The check below is really uneeded because it can fail in a lot of
+   * The check below is really unneeded because it can fail in a lot of
    * normal cases. Specifically, it is possible for sequence numbers to
    * loop back to zero once they reach 0xfff0 and to go up to 0xf7f0 in
    * which case the check below will report the two sequence numbers to
@@ -322,8 +327,8 @@ MacRxMiddle::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
                     ", frag=" << hdr->GetFragmentNumber ());
       return;
     }
-  Ptr<Packet> agregate = HandleFragments (packet, hdr, originator);
-  if (agregate == 0)
+  Ptr<Packet> aggregate = HandleFragments (packet, hdr, originator);
+  if (aggregate == 0)
     {
       return;
     }
@@ -334,7 +339,13 @@ MacRxMiddle::Receive (Ptr<Packet> packet, const WifiMacHeader *hdr)
     {
       originator->SetSequenceControl (hdr->GetSequenceControl ());
     }
-  m_callback (agregate, hdr);
+  m_callback (aggregate, hdr);
+}
+
+void
+MacRxMiddle::SetPcfCallback (Callback<void> callback)
+{
+  m_pcfCallback = callback;
 }
 
 } //namespace ns3
