@@ -21,13 +21,13 @@
 #ifndef MSDU_AGGREGATOR_H
 #define MSDU_AGGREGATOR_H
 
-#include "ns3/packet.h"
 #include "ns3/object.h"
-#include "amsdu-subframe-header.h"
 
 namespace ns3 {
 
+class AmsduSubframeHeader;
 class WifiMacHeader;
+class Packet;
 
 /**
  * \brief Aggregator used to construct A-MSDUs
