@@ -21,14 +21,13 @@
 #ifndef QOS_UTILS_H
 #define QOS_UTILS_H
 
-#include "ns3/uinteger.h"
-#include "ns3/packet.h"
-#include "wifi-mac-header.h"
-#include "ctrl-headers.h"
-#include "mgt-headers.h"
+#include "ns3/ptr.h"
 
 namespace ns3 {
 
+class Packet;
+class WifiMacHeader;
+
 /**
  * \ingroup wifi
  * This enumeration defines the Access Categories as an enumeration
