@@ -23,12 +23,14 @@
  * with Nicola Baldo and Dean Armstrong
  */
 
-#include "spectrum-wifi-phy.h"
 #include "ns3/wifi-spectrum-value-helper.h"
-#include "ns3/abort.h"
 #include "ns3/log.h"
 #include "ns3/boolean.h"
+#include "ns3/net-device.h"
+#include "ns3/node.h"
+#include "spectrum-wifi-phy.h"
 #include "wifi-spectrum-signal-parameters.h"
+#include "wifi-spectrum-phy-interface.h"
 #include "wifi-utils.h"
 
 namespace ns3 {
@@ -108,8 +110,8 @@ SpectrumWifiPhy::GetRxSpectrumModel () const
         }
       else
         {
-          uint8_t channelWidth = GetChannelWidth ();
-          NS_LOG_DEBUG ("Creating spectrum model from frequency/width pair of (" << GetFrequency () << ", " << +channelWidth << ")");
+          uint16_t channelWidth = GetChannelWidth ();
+          NS_LOG_DEBUG ("Creating spectrum model from frequency/width pair of (" << GetFrequency () << ", " << channelWidth << ")");
           m_rxSpectrumModel = WifiSpectrumValueHelper::GetSpectrumModel (GetFrequency (), channelWidth, GetBandBandwidth (), GetGuardBandwidth (channelWidth));
         }
     }
@@ -133,8 +135,8 @@ SpectrumWifiPhy::ResetSpectrumModel (void)
 {
   NS_LOG_FUNCTION (this);
   NS_ASSERT_MSG (IsInitialized (), "Executing method before run-time");
-  uint8_t channelWidth = GetChannelWidth ();
-  NS_LOG_DEBUG ("Run-time change of spectrum model from frequency/width pair of (" << GetFrequency () << ", " << +channelWidth << ")");
+  uint16_t channelWidth = GetChannelWidth ();
+  NS_LOG_DEBUG ("Run-time change of spectrum model from frequency/width pair of (" << GetFrequency () << ", " << channelWidth << ")");
   // Replace existing spectrum model with new one, and must call AddRx ()
   // on the SpectrumChannel to provide this new spectrum model to it
   m_rxSpectrumModel = WifiSpectrumValueHelper::GetSpectrumModel (GetFrequency (), channelWidth, GetBandBandwidth (), GetGuardBandwidth (channelWidth));
@@ -164,9 +166,9 @@ SpectrumWifiPhy::SetFrequency (uint16_t freq)
 }
 
 void
-SpectrumWifiPhy::SetChannelWidth (uint8_t channelwidth)
+SpectrumWifiPhy::SetChannelWidth (uint16_t channelwidth)
 {
-  NS_LOG_FUNCTION (this << +channelwidth);
+  NS_LOG_FUNCTION (this << channelwidth);
   WifiPhy::SetChannelWidth (channelwidth);
   if (IsInitialized ())
     {
@@ -228,7 +230,7 @@ SpectrumWifiPhy::StartRx (Ptr<SpectrumSignalParameters> rxParams)
   // Integrate over our receive bandwidth (i.e., all that the receive
   // spectral mask representing our filtering allows) to find the
   // total energy apparent to the "demodulator".
-  uint8_t channelWidth = GetChannelWidth ();
+  uint16_t channelWidth = GetChannelWidth ();
   Ptr<SpectrumValue> filter = WifiSpectrumValueHelper::CreateRfFilter (GetFrequency (), channelWidth, GetBandBandwidth (), GetGuardBandwidth (channelWidth));
   SpectrumValue filteredSignal = (*filter) * (*receivedSignalPsd);
   // Add receiver antenna gain
@@ -260,12 +262,6 @@ SpectrumWifiPhy::StartRx (Ptr<SpectrumSignalParameters> rxParams)
   StartReceivePreambleAndHeader (packet, rxPowerW, rxDuration);
 }
 
-Ptr<WifiSpectrumPhyInterface>
-SpectrumWifiPhy::GetSpectrumPhy (void) const
-{
-  return m_wifiSpectrumPhyInterface;
-}
-
 Ptr<AntennaModel>
 SpectrumWifiPhy::GetRxAntenna (void) const
 {
@@ -289,9 +285,9 @@ SpectrumWifiPhy::CreateWifiSpectrumPhyInterface (Ptr<NetDevice> device)
 }
 
 Ptr<SpectrumValue>
-SpectrumWifiPhy::GetTxPowerSpectralDensity (uint16_t centerFrequency, uint8_t channelWidth, double txPowerW, WifiModulationClass modulationClass) const
+SpectrumWifiPhy::GetTxPowerSpectralDensity (uint16_t centerFrequency, uint16_t channelWidth, double txPowerW, WifiModulationClass modulationClass) const
 {
-  NS_LOG_FUNCTION (centerFrequency << +channelWidth << txPowerW);
+  NS_LOG_FUNCTION (centerFrequency << channelWidth << txPowerW);
   Ptr<SpectrumValue> v;
   switch (modulationClass)
     {
@@ -318,17 +314,17 @@ SpectrumWifiPhy::GetTxPowerSpectralDensity (uint16_t centerFrequency, uint8_t ch
   return v;
 }
 
-uint32_t
+uint16_t
 SpectrumWifiPhy::GetCenterFrequencyForChannelWidth (WifiTxVector txVector) const
 {
   NS_LOG_FUNCTION (this << txVector);
-  uint32_t centerFrequencyForSupportedWidth = GetFrequency ();
-  uint8_t supportedWidth = GetChannelWidth ();
-  uint8_t currentWidth = txVector.GetChannelWidth ();
+  uint16_t centerFrequencyForSupportedWidth = GetFrequency ();
+  uint16_t supportedWidth = GetChannelWidth ();
+  uint16_t currentWidth = txVector.GetChannelWidth ();
   if (currentWidth != supportedWidth)
     {
-      uint32_t startingFrequency = centerFrequencyForSupportedWidth - static_cast<uint32_t> (supportedWidth / 2);
-      return startingFrequency + static_cast<uint32_t> (currentWidth / 2); // primary channel is in the lower part (for the time being)
+      uint16_t startingFrequency = centerFrequencyForSupportedWidth - (supportedWidth / 2);
+      return startingFrequency + (currentWidth / 2); // primary channel is in the lower part (for the time being)
     }
   return centerFrequencyForSupportedWidth;
 }
@@ -387,10 +383,10 @@ SpectrumWifiPhy::GetBandBandwidth (void) const
   return bandBandwidth;
 }
 
-uint8_t
-SpectrumWifiPhy::GetGuardBandwidth (uint8_t currentChannelWidth) const
+uint16_t
+SpectrumWifiPhy::GetGuardBandwidth (uint16_t currentChannelWidth) const
 {
-  uint8_t guardBandwidth = 0;
+  uint16_t guardBandwidth = 0;
   if (currentChannelWidth == 22)
     {
       //handle case of use of legacy DSSS transmission
