@@ -27,13 +27,14 @@
 #define SPECTRUM_WIFI_PHY_H
 
 #include "ns3/antenna-model.h"
-#include "wifi-phy.h"
-#include "wifi-spectrum-phy-interface.h"
 #include "ns3/spectrum-channel.h"
-#include "ns3/spectrum-interference.h"
+#include "ns3/spectrum-model.h"
+#include "wifi-phy.h"
 
 namespace ns3 {
 
+class WifiSpectrumPhyInterface;
+
 /**
  * \brief 802.11 PHY layer model
  * \ingroup wifi
@@ -108,7 +109,7 @@ public:
    * \param txVector the TXVECTOR that has the channel width that is to be used
    * \return the center frequency corresponding to the channel width to be used
    */
-  uint32_t GetCenterFrequencyForChannelWidth (WifiTxVector txVector) const;
+  uint16_t GetCenterFrequencyForChannelWidth (WifiTxVector txVector) const;
 
   /**
    * Method to encapsulate the creation of the WifiSpectrumPhyInterface
@@ -118,10 +119,6 @@ public:
    * \param device pointer to the NetDevice object including this new object
    */
   void CreateWifiSpectrumPhyInterface (Ptr<NetDevice> device);
-  /**
-   * \return pointer to WifiSpectrumPhyInterface associated with this Phy
-   */
-  Ptr<WifiSpectrumPhyInterface> GetSpectrumPhy (void) const;
   /**
    * \param antenna an AntennaModel to include in the transmitted
    * SpectrumSignalParameters (in case any objects downstream of the
@@ -163,7 +160,7 @@ public:
    * to the current channel bandwidth (which can be different from devices max
    * channel width).
    */
-  uint8_t GetGuardBandwidth (uint8_t currentChannelWidth) const;
+  uint16_t GetGuardBandwidth (uint16_t currentChannelWidth) const;
 
   /**
    * Callback invoked when the Phy model starts to process a signal
@@ -184,7 +181,7 @@ public:
 
   virtual void SetFrequency (uint16_t freq);
 
-  virtual void SetChannelWidth (uint8_t channelwidth);
+  virtual void SetChannelWidth (uint16_t channelwidth);
 
   virtual void ConfigureStandard (WifiPhyStandard standard);
 
@@ -205,7 +202,7 @@ private:
    * This is a helper function to create the right Tx PSD corresponding
    * to the standard in use.
    */
-  Ptr<SpectrumValue> GetTxPowerSpectralDensity (uint16_t centerFrequency, uint8_t channelWidth, double txPowerW, WifiModulationClass modulationClass) const;
+  Ptr<SpectrumValue> GetTxPowerSpectralDensity (uint16_t centerFrequency, uint16_t channelWidth, double txPowerW, WifiModulationClass modulationClass) const;
 
   /**
    * Perform run-time spectrum model change
