@@ -321,12 +321,6 @@ VhtCapabilities::SetTxHighestSupportedLgiDataRate (uint16_t supporteddatarate)
   m_txHighestSupportedLongGuardIntervalDataRate = supporteddatarate;
 }
 
-uint8_t
-VhtCapabilities::GetMaxMpduLength () const
-{
-  return m_maxMpduLength;
-}
-
 uint8_t
 VhtCapabilities::GetSupportedChannelWidthSet () const
 {
@@ -339,18 +333,6 @@ VhtCapabilities::GetRxLdpc () const
   return m_rxLdpc;
 }
 
-uint8_t
-VhtCapabilities::GetShortGuardIntervalFor80Mhz () const
-{
-  return m_shortGuardIntervalFor80Mhz;
-}
-
-uint8_t
-VhtCapabilities::GetShortGuardIntervalFor160Mhz () const
-{
-  return m_shortGuardIntervalFor160Mhz;
-}
-
 uint8_t
 VhtCapabilities::GetRxStbc () const
 {
@@ -363,12 +345,6 @@ VhtCapabilities::GetTxStbc () const
   return m_txStbc;
 }
 
-uint8_t
-VhtCapabilities::GetMaxAmpduLengthExponent () const
-{
-  return m_maxAmpduLengthExponent;
-}
-
 bool
 VhtCapabilities::IsSupportedMcs (uint8_t mcs, uint8_t nss) const
 {
@@ -388,46 +364,12 @@ VhtCapabilities::IsSupportedMcs (uint8_t mcs, uint8_t nss) const
   return false;
 }
 
-uint16_t
-VhtCapabilities::GetRxMcsMap () const
-{
-  uint16_t val = 0;
-  uint8_t n;
-  for (uint8_t i = 0; i < 8; i++)
-    {
-      n = i * 2;
-      val |= (m_rxMcsMap[i] & 0x03) << n;
-    }
-  return val;
-}
-
-uint16_t
-VhtCapabilities::GetTxMcsMap () const
-{
-  uint16_t val = 0;
-  uint8_t n;
-  for (uint8_t i = 0; i < 8; i++)
-    {
-      n = i * 2;
-      val |= (m_txMcsMap[i] & 0x03) << n;
-    }
-  return val;
-}
-
 uint16_t
 VhtCapabilities::GetRxHighestSupportedLgiDataRate () const
 {
   return m_rxHighestSupportedLongGuardIntervalDataRate;
 }
 
-uint16_t
-VhtCapabilities::GetTxHighestSupportedLgiDataRate () const
-{
-  return m_txHighestSupportedLongGuardIntervalDataRate;
-}
-
-ATTRIBUTE_HELPER_CPP (VhtCapabilities);
-
 /**
  * output stream output operator
  *
@@ -444,23 +386,4 @@ operator << (std::ostream &os, const VhtCapabilities &VhtCapabilities)
   return os;
 }
 
-/**
- * input stream input operator
- *
- * \param is input stream
- * \param VhtCapabilities the VHT capabilities
- *
- * \returns input stream
- */
-std::istream &operator >> (std::istream &is,VhtCapabilities &VhtCapabilities)
-{
-  uint32_t c1;
-  uint64_t c2;
-  is >>  c1 >> c2;
-  VhtCapabilities.SetVhtCapabilitiesInfo (c1);
-  VhtCapabilities.SetSupportedMcsAndNssSet (c2);
-
-  return is;
-}
-
 } //namespace ns3
