@@ -20,6 +20,7 @@
  *          Mirko Banchi <mk.banchi@gmail.com>
  */
 
+#include "ns3/nstime.h"
 #include "ns3/address-utils.h"
 #include "wifi-mac-header.h"
 
@@ -44,13 +45,15 @@ enum
   SUBTYPE_CTL_BACKRESP = 9,
   SUBTYPE_CTL_RTS = 11,
   SUBTYPE_CTL_CTS = 12,
-  SUBTYPE_CTL_ACK = 13
+  SUBTYPE_CTL_ACK = 13,
+  SUBTYPE_CTL_END = 14,
+  SUBTYPE_CTL_END_ACK = 15
 };
 
 WifiMacHeader::WifiMacHeader ()
   : m_ctrlMoreData (0),
     m_ctrlWep (0),
-    m_ctrlOrder (1),
+    m_ctrlOrder (0),
     m_amsduPresent (0)
 {
 }
@@ -108,7 +111,7 @@ WifiMacHeader::SetAddr4 (Mac48Address address)
 }
 
 void
-WifiMacHeader::SetType (WifiMacType type)
+WifiMacHeader::SetType (WifiMacType type, bool resetToDsFromDs)
 {
   switch (type)
     {
@@ -136,6 +139,14 @@ WifiMacHeader::SetType (WifiMacType type)
       m_ctrlType = TYPE_CTL;
       m_ctrlSubtype = SUBTYPE_CTL_ACK;
       break;
+    case WIFI_MAC_CTL_END:
+      m_ctrlType = TYPE_CTL;
+      m_ctrlSubtype = SUBTYPE_CTL_END;
+      break;
+    case WIFI_MAC_CTL_END_ACK:
+      m_ctrlType = TYPE_CTL;
+      m_ctrlSubtype = SUBTYPE_CTL_END_ACK;
+      break;
     case WIFI_MAC_MGT_ASSOCIATION_REQUEST:
       m_ctrlType = TYPE_MGT;
       m_ctrlSubtype = 0;
@@ -249,14 +260,24 @@ WifiMacHeader::SetType (WifiMacType type)
       m_ctrlSubtype = 15;
       break;
     }
-  m_ctrlToDs = 0;
-  m_ctrlFromDs = 0;
+  if (resetToDsFromDs)
+    {
+      m_ctrlToDs = 0;
+      m_ctrlFromDs = 0;
+    }
+}
+
+void
+WifiMacHeader::SetRawDuration (uint16_t duration)
+{
+  NS_ASSERT (duration <= 32768);
+  m_duration = duration;
 }
 
 void
 WifiMacHeader::SetDuration (Time duration)
 {
-  int64_t duration_us = ceil (static_cast<double> (duration.GetNanoSeconds ()) / 1000);
+  int64_t duration_us = static_cast<int64_t> (ceil (static_cast<double> (duration.GetNanoSeconds ()) / 1000));
   NS_ASSERT (duration_us >= 0 && duration_us <= 0x7fff);
   m_duration = static_cast<uint16_t> (duration_us);
 }
@@ -443,6 +464,10 @@ WifiMacHeader::GetType (void) const
           return WIFI_MAC_CTL_CTS;
         case SUBTYPE_CTL_ACK:
           return WIFI_MAC_CTL_ACK;
+        case SUBTYPE_CTL_END:
+          return WIFI_MAC_CTL_END;
+        case SUBTYPE_CTL_END_ACK:
+          return WIFI_MAC_CTL_END_ACK;
         }
       break;
     case TYPE_DATA:
@@ -524,7 +549,7 @@ WifiMacHeader::IsMgt (void) const
 }
 
 bool
-WifiMacHeader::IsCfpoll (void) const
+WifiMacHeader::IsCfPoll (void) const
 {
   switch (GetType ())
     {
@@ -542,6 +567,55 @@ WifiMacHeader::IsCfpoll (void) const
     }
 }
 
+bool
+WifiMacHeader::IsCfEnd (void) const
+{
+  switch (GetType ())
+    {
+    case WIFI_MAC_CTL_END:
+    case WIFI_MAC_CTL_END_ACK:
+      return true;
+    default:
+      return false;
+    }
+}
+
+bool
+WifiMacHeader::IsCfAck (void) const
+{
+  switch (GetType ())
+    {
+    case WIFI_MAC_DATA_CFACK:
+    case WIFI_MAC_DATA_CFACK_CFPOLL:
+    case WIFI_MAC_DATA_NULL_CFACK:
+    case WIFI_MAC_DATA_NULL_CFACK_CFPOLL:
+    case WIFI_MAC_CTL_END_ACK:
+      return true;
+    default:
+      return false;
+      break;
+    }
+}
+
+bool
+WifiMacHeader::HasData (void) const
+{
+  switch (GetType ())
+    {
+    case WIFI_MAC_DATA:
+    case WIFI_MAC_DATA_CFACK:
+    case WIFI_MAC_DATA_CFPOLL:
+    case WIFI_MAC_DATA_CFACK_CFPOLL:
+    case WIFI_MAC_QOSDATA:
+    case WIFI_MAC_QOSDATA_CFACK:
+    case WIFI_MAC_QOSDATA_CFPOLL:
+    case WIFI_MAC_QOSDATA_CFACK_CFPOLL:
+      return true;
+    default:
+      return false;
+    }
+}
+
 bool
 WifiMacHeader::IsRts (void) const
 {
@@ -644,6 +718,12 @@ WifiMacHeader::IsBlockAck (void) const
   return (GetType () == WIFI_MAC_CTL_BACKRESP) ? true : false;
 }
 
+uint16_t
+WifiMacHeader::GetRawDuration (void) const
+{
+  return m_duration;
+}
+
 Time
 WifiMacHeader::GetDuration (void) const
 {
@@ -722,13 +802,6 @@ WifiMacHeader::GetQosTid (void) const
   return m_qosTid;
 }
 
-uint8_t
-WifiMacHeader::GetQosTxopLimit (void) const
-{
-  NS_ASSERT (IsQosData ());
-  return m_qosStuff;
-}
-
 uint16_t
 WifiMacHeader::GetFrameControl (void) const
 {
@@ -799,16 +872,16 @@ WifiMacHeader::GetSize (void) const
       switch (m_ctrlSubtype)
         {
         case SUBTYPE_CTL_RTS:
+        case SUBTYPE_CTL_BACKREQ:
+        case SUBTYPE_CTL_BACKRESP:
+        case SUBTYPE_CTL_END:
+        case SUBTYPE_CTL_END_ACK:
           size = 2 + 2 + 6 + 6;
           break;
         case SUBTYPE_CTL_CTS:
         case SUBTYPE_CTL_ACK:
           size = 2 + 2 + 6;
           break;
-        case SUBTYPE_CTL_BACKREQ:
-        case SUBTYPE_CTL_BACKRESP:
-          size = 2 + 2 + 6 + 6;
-          break;
         case SUBTYPE_CTL_CTLWRAPPER:
           size = 2 + 2 + 6 + 2 + 4;
           break;
@@ -844,6 +917,8 @@ case WIFI_MAC_ ## x: \
       FOO (CTL_ACK);
       FOO (CTL_BACKREQ);
       FOO (CTL_BACKRESP);
+      FOO (CTL_END);
+      FOO (CTL_END_ACK);
 
       FOO (MGT_BEACON);
       FOO (MGT_ASSOCIATION_REQUEST);
@@ -878,8 +953,10 @@ case WIFI_MAC_ ## x: \
       return "ERROR";
     }
 #undef FOO
+#ifndef _WIN32
   // needed to make gcc 4.0.1 ppc darwin happy.
   return "BIG_ERROR";
+#endif
 }
 
 TypeId
@@ -923,10 +1000,6 @@ WifiMacHeader::Print (std::ostream &os) const
       os << "Duration/ID=" << m_duration << "us"
          << ", RA=" << m_addr1;
       break;
-    case WIFI_MAC_CTL_BACKREQ:
-    case WIFI_MAC_CTL_BACKRESP:
-    case WIFI_MAC_CTL_CTLWRAPPER:
-      break;
     case WIFI_MAC_MGT_BEACON:
     case WIFI_MAC_MGT_ASSOCIATION_REQUEST:
     case WIFI_MAC_MGT_ASSOCIATION_RESPONSE:
@@ -981,6 +1054,11 @@ WifiMacHeader::Print (std::ostream &os) const
       os << ", FragNumber=" << std::hex << (int) m_seqFrag << std::dec
          << ", SeqNumber=" << m_seqSeq;
       break;
+    case WIFI_MAC_CTL_BACKREQ:
+    case WIFI_MAC_CTL_BACKRESP:
+    case WIFI_MAC_CTL_CTLWRAPPER:
+    case WIFI_MAC_CTL_END:
+    case WIFI_MAC_CTL_END_ACK:
     case WIFI_MAC_DATA_CFACK:
     case WIFI_MAC_DATA_CFPOLL:
     case WIFI_MAC_DATA_CFACK_CFPOLL:
@@ -995,6 +1073,7 @@ WifiMacHeader::Print (std::ostream &os) const
     case WIFI_MAC_QOSDATA_NULL:
     case WIFI_MAC_QOSDATA_NULL_CFPOLL:
     case WIFI_MAC_QOSDATA_NULL_CFACK_CFPOLL:
+    default:
       break;
     }
 }
@@ -1022,15 +1101,15 @@ WifiMacHeader::Serialize (Buffer::Iterator i) const
       switch (m_ctrlSubtype)
         {
         case SUBTYPE_CTL_RTS:
+        case SUBTYPE_CTL_BACKREQ:
+        case SUBTYPE_CTL_BACKRESP:
+        case SUBTYPE_CTL_END:
+        case SUBTYPE_CTL_END_ACK:
           WriteTo (i, m_addr2);
           break;
         case SUBTYPE_CTL_CTS:
         case SUBTYPE_CTL_ACK:
           break;
-        case SUBTYPE_CTL_BACKREQ:
-        case SUBTYPE_CTL_BACKRESP:
-          WriteTo (i, m_addr2);
-          break;
         default:
           //NOTREACHED
           NS_ASSERT (false);
@@ -1077,15 +1156,15 @@ WifiMacHeader::Deserialize (Buffer::Iterator start)
       switch (m_ctrlSubtype)
         {
         case SUBTYPE_CTL_RTS:
+        case SUBTYPE_CTL_BACKREQ:
+        case SUBTYPE_CTL_BACKRESP:
+        case SUBTYPE_CTL_END:
+        case SUBTYPE_CTL_END_ACK:
           ReadFrom (i, m_addr2);
           break;
         case SUBTYPE_CTL_CTS:
         case SUBTYPE_CTL_ACK:
           break;
-        case SUBTYPE_CTL_BACKREQ:
-        case SUBTYPE_CTL_BACKRESP:
-          ReadFrom (i, m_addr2);
-          break;
         }
       break;
     case TYPE_DATA:
