@@ -22,14 +22,15 @@
 #define WIFI_PHY_STATE_HELPER_H
 
 #include "ns3/object.h"
-#include "wifi-phy-state.h"
 #include "ns3/callback.h"
 #include "ns3/traced-callback.h"
+#include "ns3/nstime.h"
+#include "wifi-phy-state.h"
 #include "wifi-preamble.h"
-#include "wifi-phy-listener.h"
 
 namespace ns3 {
 
+class WifiPhyListener;
 class WifiTxVector;
 class WifiMode;
 class Packet;
