@@ -44,7 +44,7 @@ WifiTxVector::WifiTxVector (WifiMode mode,
                             uint8_t nTx,
                             uint8_t nss,
                             uint8_t ness,
-                            uint8_t channelWidth,
+                            uint16_t channelWidth,
                             bool aggregation,
                             bool stbc)
   : m_mode (mode),
@@ -88,7 +88,7 @@ WifiTxVector::GetPreambleType (void) const
   return m_preamble;
 }
 
-uint8_t
+uint16_t
 WifiTxVector::GetChannelWidth (void) const
 {
   return m_channelWidth;
@@ -151,7 +151,7 @@ WifiTxVector::SetPreambleType (WifiPreamble preamble)
 }
 
 void
-WifiTxVector::SetChannelWidth (uint8_t channelWidth)
+WifiTxVector::SetChannelWidth (uint16_t channelWidth)
 {
   m_channelWidth = channelWidth;
 }
@@ -229,7 +229,7 @@ std::ostream & operator << ( std::ostream &os, const WifiTxVector &v)
   os << "mode: " << v.GetMode () <<
     " txpwrlvl: " << +v.GetTxPowerLevel () <<
     " preamble: " << v.GetPreambleType () <<
-    " channel width: " << +v.GetChannelWidth () <<
+    " channel width: " << v.GetChannelWidth () <<
     " GI: " << v.GetGuardInterval () <<
     " NTx: " << +v.GetNTx () <<
     " Nss: " << +v.GetNss () <<
