@@ -21,11 +21,12 @@
  *          Sébastien Deronne <sebastien.deronne@gmail.com>
  */
 
+#include "ns3/string.h"
 #include "ns3/yans-wifi-helper.h"
 #include "ns3/mobility-helper.h"
 #include "ns3/wifi-net-device.h"
 #include "ns3/adhoc-wifi-mac.h"
-#include "ns3/propagation-delay-model.h"
+#include "ns3/ap-wifi-mac.h"
 #include "ns3/propagation-loss-model.h"
 #include "ns3/yans-error-rate-model.h"
 #include "ns3/constant-position-mobility-model.h"
@@ -33,17 +34,15 @@
 #include "ns3/pointer.h"
 #include "ns3/rng-seed-manager.h"
 #include "ns3/config.h"
-#include "ns3/string.h"
 #include "ns3/packet-socket-server.h"
 #include "ns3/packet-socket-client.h"
 #include "ns3/packet-socket-helper.h"
 #include "ns3/spectrum-wifi-helper.h"
-#include "ns3/spectrum-value.h"
 #include "ns3/multi-model-spectrum-channel.h"
 #include "ns3/wifi-spectrum-signal-parameters.h"
 #include "ns3/wifi-phy-tag.h"
-#include <tuple>
-#include <vector>
+#include "ns3/yans-wifi-phy.h"
+#include "ns3/mgt-headers.h"
 
 using namespace ns3;
 
@@ -57,25 +56,25 @@ AssignWifiRandomStreams (Ptr<WifiMac> mac, int64_t stream)
   if (rmac)
     {
       PointerValue ptr;
-      rmac->GetAttribute ("DcaTxop", ptr);
-      Ptr<DcaTxop> dcaTxop = ptr.Get<DcaTxop> ();
-      currentStream += dcaTxop->AssignStreams (currentStream);
+      rmac->GetAttribute ("Txop", ptr);
+      Ptr<Txop> txop = ptr.Get<Txop> ();
+      currentStream += txop->AssignStreams (currentStream);
 
-      rmac->GetAttribute ("VO_EdcaTxopN", ptr);
-      Ptr<EdcaTxopN> vo_edcaTxopN = ptr.Get<EdcaTxopN> ();
-      currentStream += vo_edcaTxopN->AssignStreams (currentStream);
+      rmac->GetAttribute ("VO_Txop", ptr);
+      Ptr<QosTxop> vo_txop = ptr.Get<QosTxop> ();
+      currentStream += vo_txop->AssignStreams (currentStream);
 
-      rmac->GetAttribute ("VI_EdcaTxopN", ptr);
-      Ptr<EdcaTxopN> vi_edcaTxopN = ptr.Get<EdcaTxopN> ();
-      currentStream += vi_edcaTxopN->AssignStreams (currentStream);
+      rmac->GetAttribute ("VI_Txop", ptr);
+      Ptr<QosTxop> vi_txop = ptr.Get<QosTxop> ();
+      currentStream += vi_txop->AssignStreams (currentStream);
 
-      rmac->GetAttribute ("BE_EdcaTxopN", ptr);
-      Ptr<EdcaTxopN> be_edcaTxopN = ptr.Get<EdcaTxopN> ();
-      currentStream += be_edcaTxopN->AssignStreams (currentStream);
+      rmac->GetAttribute ("BE_Txop", ptr);
+      Ptr<QosTxop> be_txop = ptr.Get<QosTxop> ();
+      currentStream += be_txop->AssignStreams (currentStream);
 
-      rmac->GetAttribute ("BK_EdcaTxopN", ptr);
-      Ptr<EdcaTxopN> bk_edcaTxopN = ptr.Get<EdcaTxopN> ();
-      bk_edcaTxopN->AssignStreams (currentStream);
+      rmac->GetAttribute ("BK_Txop", ptr);
+      Ptr<QosTxop> bk_txop = ptr.Get<QosTxop> ();
+      bk_txop->AssignStreams (currentStream);
     }
 }
 
@@ -495,9 +494,9 @@ DcfImmediateAccessBroadcastTestCase::DoRun (void)
   Ptr<WifiMac> txMac = m_mac.Create<WifiMac> ();
   txMac->ConfigureStandard (WIFI_PHY_STANDARD_80211a);
   //Fix the stream assignment to the Dcf Txop objects (backoffs)
-  //The below stream assignment will result in the DcaTxop object
+  //The below stream assignment will result in the Txop object
   //using a backoff value of zero for this test when the
-  //DcaTxop::EndTxNoAck() calls to StartBackoffNow()
+  //Txop::EndTxNoAck() calls to StartBackoffNow()
   AssignWifiRandomStreams (txMac, 23);
 
   Ptr<ConstantPositionMobilityModel> txMobility = CreateObject<ConstantPositionMobilityModel> ();
@@ -1185,7 +1184,7 @@ private:
   /**
    * A tuple of {starting frequency, channelWidth, Number of subbands in SpectrumModel, modulation type}
    */
-  typedef std::tuple<double, uint8_t, uint32_t, WifiModulationClass> FreqWidthSubbandModulationTuple;
+  typedef std::tuple<double, uint16_t, uint32_t, WifiModulationClass> FreqWidthSubbandModulationTuple;
   std::vector<FreqWidthSubbandModulationTuple> m_distinctTuples; ///< vector of distinct {starting frequency, channelWidth, Number of subbands in SpectrumModel, modulation type} tuples
 
   /**
@@ -1218,7 +1217,7 @@ Bug2483TestCase::StoreDistinctTuple (std::string context,  Ptr<SpectrumSignalPar
 {
   // Extract starting frequency and number of subbands
   Ptr<const SpectrumModel> c = txParams->psd->GetSpectrumModel ();
-  uint32_t numBands = c->GetNumBands ();
+  std::size_t numBands = c->GetNumBands ();
   double startingFreq = c->Begin ()->fl;
 
   // Get channel bandwidth and modulation class
@@ -1231,7 +1230,7 @@ Bug2483TestCase::StoreDistinctTuple (std::string context,  Ptr<SpectrumSignalPar
       return;
     }
   WifiTxVector txVector = tag.GetWifiTxVector ();
-  uint8_t channelWidth = txVector.GetChannelWidth ();
+  uint16_t channelWidth = txVector.GetChannelWidth ();
   WifiModulationClass modulationClass = txVector.GetMode ().GetModulationClass ();
 
   // Build a tuple and check if seen before (if so store it)
@@ -1268,7 +1267,7 @@ Bug2483TestCase::DoRun (void)
   Config::SetDefault ("ns3::WifiRemoteStationManager::RtsCtsThreshold", StringValue ("500")); // so as to force RTS/CTS for data frames
   Config::SetDefault ("ns3::WifiPhy::CcaMode1Threshold", DoubleValue (-62.0));
 
-  uint8_t channelWidth = 40; // at least 40 MHz expected here
+  uint16_t channelWidth = 40; // at least 40 MHz expected here
 
   NodeContainer wifiStaNode;
   wifiStaNode.Create (1);
@@ -1330,7 +1329,7 @@ Bug2483TestCase::DoRun (void)
   Simulator::Destroy ();
 
   // {starting frequency, channelWidth, Number of subbands in SpectrumModel, modulation type} tuples
-  uint8_t numberTuples = m_distinctTuples.size ();
+  std::size_t numberTuples = m_distinctTuples.size ();
   NS_TEST_ASSERT_MSG_EQ (numberTuples, 2, "Only two distinct tuples expected");
   NS_TEST_ASSERT_MSG_EQ (std::get<0> (m_distinctTuples[0]) - 20e6, std::get<0> (m_distinctTuples[1]), "The starting frequency of the first tuple should be shifted 20 MHz to the right wrt second tuple");
   // Note that the first tuple should the one initiated by the beacon, i.e. legacy OFDM (20 MHz)
@@ -1442,7 +1441,7 @@ Bug2831TestCase::DoRun (void)
   ObjectFactory propDelay;
   propDelay.SetTypeId ("ns3::ConstantSpeedPropagationDelayModel");
   Ptr<PropagationDelayModel> propagationDelay = propDelay.Create<PropagationDelayModel> ();
-  Ptr<PropagationLossModel> propagationLoss = CreateObject<RandomPropagationLossModel> ();
+  Ptr<PropagationLossModel> propagationLoss = CreateObject<FriisPropagationLossModel> ();
   channel->SetPropagationDelayModel (propagationDelay);
   channel->SetPropagationLossModel (propagationLoss);
 
@@ -1450,14 +1449,15 @@ Bug2831TestCase::DoRun (void)
   Ptr<WifiNetDevice> apDev = CreateObject<WifiNetDevice> ();
   ObjectFactory mac;
   mac.SetTypeId ("ns3::ApWifiMac");
+  mac.Set ("EnableBeaconJitter", BooleanValue (false));
   Ptr<WifiMac> apMac = mac.Create<WifiMac> ();
-  apMac->ConfigureStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+  apMac->ConfigureStandard (WIFI_PHY_STANDARD_80211ax_5GHZ);
 
   Ptr<Node> staNode = CreateObject<Node> ();
   Ptr<WifiNetDevice> staDev = CreateObject<WifiNetDevice> ();
   mac.SetTypeId ("ns3::StaWifiMac");
   Ptr<WifiMac> staMac = mac.Create<WifiMac> ();
-  staMac->ConfigureStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+  staMac->ConfigureStandard (WIFI_PHY_STANDARD_80211ax_5GHZ);
 
   Ptr<ConstantPositionMobilityModel> apMobility = CreateObject<ConstantPositionMobilityModel> ();
   apMobility->SetPosition (Vector (0.0, 0.0, 0.0));
@@ -1469,7 +1469,7 @@ Bug2831TestCase::DoRun (void)
   m_apPhy->SetChannel (channel);
   m_apPhy->SetMobility (apMobility);
   m_apPhy->SetDevice (apDev);
-  m_apPhy->ConfigureStandard (WIFI_PHY_STANDARD_80211n_5GHZ);
+  m_apPhy->ConfigureStandard (WIFI_PHY_STANDARD_80211ax_5GHZ);
   m_apPhy->SetChannelNumber (36);
   m_apPhy->SetChannelWidth (20);
 
@@ -1482,7 +1482,7 @@ Bug2831TestCase::DoRun (void)
   m_staPhy->SetChannel (channel);
   m_staPhy->SetMobility (staMobility);
   m_staPhy->SetDevice (apDev);
-  m_staPhy->ConfigureStandard (WIFI_PHY_STANDARD_80211ac);
+  m_staPhy->ConfigureStandard (WIFI_PHY_STANDARD_80211ax_5GHZ);
   m_staPhy->SetChannelNumber (36);
   m_staPhy->SetChannelWidth (20);
 
@@ -1514,6 +1514,182 @@ Bug2831TestCase::DoRun (void)
   NS_TEST_ASSERT_MSG_EQ (m_countOperationalChannelWidth40, 20, "Incorrect operational channel width after channel change");
 }
 
+//-----------------------------------------------------------------------------
+/**
+ * Make sure that Wifi STA is correctly associating to the best AP (i.e.,
+ * nearest from STA). We consider 3 AP and 1 STA. This test case consisted of
+ * three sub tests:
+ *   - The best AP sends its beacon later than the other APs. STA is expected
+ *     to associate to the best AP.
+ *   - The STA is using active scanning instead of passive, the rest of the
+ *     APs works normally. STA is expected to associate to the best AP
+ *   - The nearest AP is turned off after sending beacon and while STA is
+ *     still scanning. STA is expected to associate to the second best AP.
+ *
+ * See \bugid{2399}
+ * \todo Add explicit association refusal test if ns-3 implemented it.
+ */
+
+class StaWifiMacScanningTestCase : public TestCase
+{
+public:
+  StaWifiMacScanningTestCase ();
+  virtual ~StaWifiMacScanningTestCase ();
+  virtual void DoRun (void);
+
+private:
+  /**
+   * Callback function on STA assoc event
+   * \param context context string
+   * \param bssid the associated AP's bssid
+   */
+  void AssocCallback (std::string context, Mac48Address bssid);
+  /**
+   * Turn beacon generation on the AP node
+   * \param apNode the AP node
+   */
+  void TurnBeaconGenerationOn (Ptr<Node> apNode);
+  /**
+   * Turn the AP node off
+   * \param apNode the AP node
+   */
+  void TurnApOff (Ptr<Node> apNode);
+  /**
+   * Setup test
+   * \param nearestApBeaconGeneration set BeaconGeneration attribute of the nearest AP
+   * \param staActiveProbe set ActiveProbing attribute of the STA
+   * \return node container containing all nodes
+   */
+  NodeContainer Setup (bool nearestApBeaconGeneration, bool staActiveProbe);
+
+  Mac48Address m_associatedApBssid; ///< Associated AP's bssid
+};
+
+StaWifiMacScanningTestCase::StaWifiMacScanningTestCase ()
+  : TestCase ("Test case for StaWifiMac scanning capability")
+{
+}
+
+StaWifiMacScanningTestCase::~StaWifiMacScanningTestCase ()
+{
+}
+
+void
+StaWifiMacScanningTestCase::AssocCallback (std::string context, Mac48Address bssid)
+{
+  m_associatedApBssid = bssid;
+}
+
+void
+StaWifiMacScanningTestCase::TurnBeaconGenerationOn (Ptr<Node> apNode)
+{
+  Ptr<WifiNetDevice> netDevice = DynamicCast<WifiNetDevice> (apNode->GetDevice (0));
+  Ptr<ApWifiMac> mac = DynamicCast<ApWifiMac> (netDevice->GetMac ());
+  mac->SetAttribute ("BeaconGeneration", BooleanValue (true));
+}
+
+void
+StaWifiMacScanningTestCase::TurnApOff (Ptr<Node> apNode)
+{
+  Ptr<WifiNetDevice> netDevice = DynamicCast<WifiNetDevice> (apNode->GetDevice (0));
+  Ptr<WifiPhy> phy = netDevice->GetPhy ();
+  phy->SetOffMode();
+}
+
+NodeContainer
+StaWifiMacScanningTestCase::Setup (bool nearestApBeaconGeneration, bool staActiveProbe)
+{
+  NodeContainer apNodes;
+  apNodes.Create (2);
+
+  Ptr<Node> apNodeNearest = CreateObject<Node> ();
+  Ptr<Node> staNode = CreateObject<Node> ();
+
+  YansWifiPhyHelper phy = YansWifiPhyHelper::Default ();
+  YansWifiChannelHelper channel = YansWifiChannelHelper::Default ();
+  phy.SetChannel (channel.Create ());
+
+  WifiHelper wifi;
+  wifi.SetStandard (WIFI_PHY_STANDARD_80211n_2_4GHZ);
+  wifi.SetRemoteStationManager ("ns3::ConstantRateWifiManager");
+
+  WifiMacHelper mac;
+  NetDeviceContainer apDevice, apDeviceNearest;
+  mac.SetType ("ns3::ApWifiMac",
+               "BeaconGeneration", BooleanValue (true));
+  apDevice = wifi.Install (phy, mac, apNodes);
+  mac.SetType ("ns3::ApWifiMac",
+               "BeaconGeneration", BooleanValue (nearestApBeaconGeneration));
+  apDeviceNearest = wifi.Install (phy, mac, apNodeNearest);
+
+  NetDeviceContainer staDevice;
+  mac.SetType ("ns3::StaWifiMac",
+               "ActiveProbing", BooleanValue (staActiveProbe));
+  staDevice = wifi.Install (phy, mac, staNode);
+
+  MobilityHelper mobility;
+  Ptr<ListPositionAllocator> positionAlloc = CreateObject<ListPositionAllocator> ();
+  positionAlloc->Add (Vector (0.0, 0.0, 0.0));  // Furthest AP
+  positionAlloc->Add (Vector (10.0, 0.0, 0.0)); // Second nearest AP
+  positionAlloc->Add (Vector (5.0, 5.0, 0.0));  // Nearest AP
+  positionAlloc->Add (Vector (6.0, 5.0, 0.0));  // STA
+  mobility.SetPositionAllocator (positionAlloc);
+
+  mobility.SetMobilityModel ("ns3::ConstantPositionMobilityModel");
+  mobility.Install (apNodes);
+  mobility.Install (apNodeNearest);
+  mobility.Install (staNode);
+
+  Config::Connect ("/NodeList/*/DeviceList/*/$ns3::WifiNetDevice/Mac/$ns3::StaWifiMac/Assoc", MakeCallback (&StaWifiMacScanningTestCase::AssocCallback, this));
+
+  NodeContainer allNodes = NodeContainer (apNodes, apNodeNearest, staNode);
+  return allNodes;
+}
+
+void
+StaWifiMacScanningTestCase::DoRun (void)
+{
+  {
+    NodeContainer nodes = Setup (false, false);
+    Ptr<Node> nearestAp = nodes.Get (2);
+    Mac48Address nearestApAddr = DynamicCast<WifiNetDevice> (nearestAp->GetDevice (0))->GetMac ()->GetAddress ();
+
+    Simulator::Schedule (Seconds (0.05), &StaWifiMacScanningTestCase::TurnBeaconGenerationOn, this, nearestAp);
+
+    Simulator::Stop (Seconds (0.2));
+    Simulator::Run ();
+    Simulator::Destroy ();
+
+    NS_TEST_ASSERT_MSG_EQ (m_associatedApBssid, nearestApAddr, "STA is associated to the wrong AP");
+  }
+  m_associatedApBssid = Mac48Address ();
+  {
+    NodeContainer nodes = Setup (true, true);
+    Ptr<Node> nearestAp = nodes.Get (2);
+    Mac48Address nearestApAddr = DynamicCast<WifiNetDevice> (nearestAp->GetDevice (0))->GetMac ()->GetAddress ();
+
+    Simulator::Stop (Seconds (0.2));
+    Simulator::Run ();
+    Simulator::Destroy ();
+
+    NS_TEST_ASSERT_MSG_EQ (m_associatedApBssid, nearestApAddr, "STA is associated to the wrong AP");
+  }
+  m_associatedApBssid = Mac48Address ();
+  {
+    NodeContainer nodes = Setup (true, false);
+    Ptr<Node> nearestAp = nodes.Get (2);
+    Mac48Address secondNearestApAddr = DynamicCast<WifiNetDevice> (nodes.Get (1)->GetDevice (0))->GetMac ()->GetAddress ();
+
+    Simulator::Schedule (Seconds (0.1), &StaWifiMacScanningTestCase::TurnApOff, this, nearestAp);
+
+    Simulator::Stop (Seconds (1.5));
+    Simulator::Run ();
+    Simulator::Destroy ();
+
+    NS_TEST_ASSERT_MSG_EQ (m_associatedApBssid, secondNearestApAddr, "STA is associated to the wrong AP");
+  }
+}
+
 /**
  * \ingroup wifi-test
  * \ingroup tests
@@ -1538,6 +1714,7 @@ WifiTestSuite::WifiTestSuite ()
   AddTestCase (new Bug2222TestCase, TestCase::QUICK); //Bug 2222
   AddTestCase (new Bug2483TestCase, TestCase::QUICK); //Bug 2483
   AddTestCase (new Bug2831TestCase, TestCase::QUICK); //Bug 2831
+  AddTestCase (new StaWifiMacScanningTestCase, TestCase::QUICK); //Bug 2399
 }
 
 static WifiTestSuite g_wifiTestSuite; ///< the test suite
